Class: CybridApiBank::AccountAssociationBankModel
- Inherits:
-
Object
- Object
- CybridApiBank::AccountAssociationBankModel
- Defined in:
- lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#asset ⇒ Object
The account asset, e.g., USD.
-
#bank_guid ⇒ Object
The account's bank identifier.
-
#counterparty_guid ⇒ Object
The account's counterparty identifier.
-
#customer_guid ⇒ Object
The account's customer identifier.
-
#executed_amount ⇒ Object
The executed amount in base units transferred from or to the account.
-
#guid ⇒ Object
Auto-generated unique identifier for the transfer account.
-
#intermediate_requested ⇒ Object
Whether this account was explicitly requested by the caller as an intermediate account.
-
#organization_guid ⇒ Object
The account's organization identifier.
-
#payment_rail ⇒ Object
The desired payment rail to use to initiate a fiat transfer.
-
#quoted_amount ⇒ Object
The quoted amount in base units to transfer from or to the account.
-
#requested_amount ⇒ Object
The requested amount in base units intended to transfer from or to the account.
-
#type ⇒ Object
The type of transfer account; one of trading, fiat, external_bank_account, or external_wallet.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountAssociationBankModel
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountAssociationBankModel
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::AccountAssociationBankModel` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::AccountAssociationBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'guid') self.guid = attributes[:'guid'] else self.guid = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'organization_guid') self.organization_guid = attributes[:'organization_guid'] end if attributes.key?(:'bank_guid') self.bank_guid = attributes[:'bank_guid'] end if attributes.key?(:'customer_guid') self.customer_guid = attributes[:'customer_guid'] end if attributes.key?(:'counterparty_guid') self.counterparty_guid = attributes[:'counterparty_guid'] end if attributes.key?(:'asset') self.asset = attributes[:'asset'] else self.asset = nil end if attributes.key?(:'requested_amount') self.requested_amount = attributes[:'requested_amount'] end if attributes.key?(:'quoted_amount') self.quoted_amount = attributes[:'quoted_amount'] end if attributes.key?(:'executed_amount') self.executed_amount = attributes[:'executed_amount'] end if attributes.key?(:'payment_rail') self.payment_rail = attributes[:'payment_rail'] end if attributes.key?(:'intermediate_requested') self.intermediate_requested = attributes[:'intermediate_requested'] end end |
Instance Attribute Details
#asset ⇒ Object
The account asset, e.g., USD.
37 38 39 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 37 def asset @asset end |
#bank_guid ⇒ Object
The account's bank identifier.
28 29 30 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 28 def bank_guid @bank_guid end |
#counterparty_guid ⇒ Object
The account's counterparty identifier.
34 35 36 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 34 def counterparty_guid @counterparty_guid end |
#customer_guid ⇒ Object
The account's customer identifier.
31 32 33 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 31 def customer_guid @customer_guid end |
#executed_amount ⇒ Object
The executed amount in base units transferred from or to the account.
46 47 48 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 46 def executed_amount @executed_amount end |
#guid ⇒ Object
Auto-generated unique identifier for the transfer account.
19 20 21 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 19 def guid @guid end |
#intermediate_requested ⇒ Object
Whether this account was explicitly requested by the caller as an intermediate account.
52 53 54 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 52 def intermediate_requested @intermediate_requested end |
#organization_guid ⇒ Object
The account's organization identifier.
25 26 27 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 25 def organization_guid @organization_guid end |
#payment_rail ⇒ Object
The desired payment rail to use to initiate a fiat transfer.
49 50 51 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 49 def payment_rail @payment_rail end |
#quoted_amount ⇒ Object
The quoted amount in base units to transfer from or to the account.
43 44 45 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 43 def quoted_amount @quoted_amount end |
#requested_amount ⇒ Object
The requested amount in base units intended to transfer from or to the account.
40 41 42 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 40 def requested_amount @requested_amount end |
#type ⇒ Object
The type of transfer account; one of trading, fiat, external_bank_account, or external_wallet.
22 23 24 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 22 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 426 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CybridApiBank.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
95 96 97 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 95 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 77 def self.attribute_map { :'guid' => :'guid', :'type' => :'type', :'organization_guid' => :'organization_guid', :'bank_guid' => :'bank_guid', :'customer_guid' => :'customer_guid', :'counterparty_guid' => :'counterparty_guid', :'asset' => :'asset', :'requested_amount' => :'requested_amount', :'quoted_amount' => :'quoted_amount', :'executed_amount' => :'executed_amount', :'payment_rail' => :'payment_rail', :'intermediate_requested' => :'intermediate_requested' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 402 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 118 def self.openapi_nullable Set.new([ :'organization_guid', :'bank_guid', :'customer_guid', :'counterparty_guid', :'requested_amount', :'quoted_amount', :'executed_amount', :'payment_rail', :'intermediate_requested' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 100 def self.openapi_types { :'guid' => :'String', :'type' => :'String', :'organization_guid' => :'String', :'bank_guid' => :'String', :'customer_guid' => :'String', :'counterparty_guid' => :'String', :'asset' => :'String', :'requested_amount' => :'Integer', :'quoted_amount' => :'Integer', :'executed_amount' => :'Integer', :'payment_rail' => :'String', :'intermediate_requested' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 370 def ==(o) return true if self.equal?(o) self.class == o.class && guid == o.guid && type == o.type && organization_guid == o.organization_guid && bank_guid == o.bank_guid && customer_guid == o.customer_guid && counterparty_guid == o.counterparty_guid && asset == o.asset && requested_amount == o.requested_amount && quoted_amount == o.quoted_amount && executed_amount == o.executed_amount && payment_rail == o.payment_rail && intermediate_requested == o.intermediate_requested end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 497 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
389 390 391 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 389 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
395 396 397 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 395 def hash [guid, type, organization_guid, bank_guid, customer_guid, counterparty_guid, asset, requested_amount, quoted_amount, executed_amount, payment_rail, intermediate_requested].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 204 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @guid.nil? invalid_properties.push('invalid value for "guid", guid cannot be nil.') end if @guid.to_s.length > 32 invalid_properties.push('invalid value for "guid", the character length must be smaller than or equal to 32.') end if @guid.to_s.length < 32 invalid_properties.push('invalid value for "guid", the character length must be great than or equal to 32.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if !@organization_guid.nil? && @organization_guid.to_s.length > 32 invalid_properties.push('invalid value for "organization_guid", the character length must be smaller than or equal to 32.') end if !@organization_guid.nil? && @organization_guid.to_s.length < 32 invalid_properties.push('invalid value for "organization_guid", the character length must be great than or equal to 32.') end if !@bank_guid.nil? && @bank_guid.to_s.length > 32 invalid_properties.push('invalid value for "bank_guid", the character length must be smaller than or equal to 32.') end if !@bank_guid.nil? && @bank_guid.to_s.length < 32 invalid_properties.push('invalid value for "bank_guid", the character length must be great than or equal to 32.') end if !@customer_guid.nil? && @customer_guid.to_s.length > 32 invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.') end if !@customer_guid.nil? && @customer_guid.to_s.length < 32 invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.') end if !@counterparty_guid.nil? && @counterparty_guid.to_s.length > 32 invalid_properties.push('invalid value for "counterparty_guid", the character length must be smaller than or equal to 32.') end if !@counterparty_guid.nil? && @counterparty_guid.to_s.length < 32 invalid_properties.push('invalid value for "counterparty_guid", the character length must be great than or equal to 32.') end if @asset.nil? invalid_properties.push('invalid value for "asset", asset cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
473 474 475 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 473 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 479 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
467 468 469 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 467 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/cybrid_api_bank_ruby/models/account_association_bank_model.rb', line 264 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @guid.nil? return false if @guid.to_s.length > 32 return false if @guid.to_s.length < 32 return false if @type.nil? return false if !@organization_guid.nil? && @organization_guid.to_s.length > 32 return false if !@organization_guid.nil? && @organization_guid.to_s.length < 32 return false if !@bank_guid.nil? && @bank_guid.to_s.length > 32 return false if !@bank_guid.nil? && @bank_guid.to_s.length < 32 return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32 return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32 return false if !@counterparty_guid.nil? && @counterparty_guid.to_s.length > 32 return false if !@counterparty_guid.nil? && @counterparty_guid.to_s.length < 32 return false if @asset.nil? payment_rail_validator = EnumAttributeValidator.new('String', ["ach", "eft", "wire", "rtp", "etransfer"]) return false unless payment_rail_validator.valid?(@payment_rail) true end |