Class: CybridApiBank::AccountsBankApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AccountsBankApi



19
20
21
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_account(post_account_bank_model, opts = {}) ⇒ AccountBankModel

Create Account Creates an account. ## Account Type An Account is tied to a specific cryptocurrency or fiat and is comprised of transactions and a current balance. An account is required to allow a Bank or Customer to hold cryptocurrency or a Customer to hold fiat on the Cybrid Platform. At present, accounts can be created as trading, storage or fiat accounts and are required before a Customer can generate quotes or execute a trade or transfer. To create accounts for your Bank, omit the customer_guid parameter in the request body. To create accounts for your Customers, include the customer_guid parameter in the request body. At the bank level, invoice_operations accounts can be configured to pre-fund your customers' Lightning Network operations. ## Asset The asset is the specific cryptocurrency or fiat that the account holds, e.g., 'BTC' for Bitcoin or USD for US dollars. See the Symbols API for a complete list of cryptocurrencies and fiat supported. ## State | State | Description | |-------|-------------| | storing | The Platform is storing the account details in our private store | | created | The Platform has created the account | Required scope: accounts:execute



27
28
29
30
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 27

def (, opts = {})
  data, _status_code, _headers = (, opts)
  data
end

#create_account_with_http_info(post_account_bank_model, opts = {}) ⇒ Array<(AccountBankModel, Integer, Hash)>

Create Account Creates an account. ## Account Type An Account is tied to a specific cryptocurrency or fiat and is comprised of transactions and a current balance. An account is required to allow a Bank or Customer to hold cryptocurrency or a Customer to hold fiat on the Cybrid Platform. At present, accounts can be created as `trading`, `storage` or `fiat ` accounts and are required before a Customer can generate quotes or execute a `trade` or `transfer`. To create accounts for your Bank, omit the `customer_guid` parameter in the request body. To create accounts for your Customers, include the `customer_guid` parameter in the request body. At the bank level, `invoice_operations` accounts can be configured to pre-fund your customers' Lightning Network operations. ## Asset The asset is the specific cryptocurrency or fiat that the account holds, e.g., 'BTC' for Bitcoin or `USD` for US dollars. See the Symbols API for a complete list of cryptocurrencies and fiat supported. ## State | State | Description | |-------|-------------| | storing | The Platform is storing the account details in our private store | | created | The Platform has created the account | Required scope: accounts:execute



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 37

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountsBankApi.create_account ...'
  end
  # verify the required parameter 'post_account_bank_model' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'post_account_bank_model' when calling AccountsBankApi.create_account"
  end
  # resource path
  local_var_path = '/api/accounts'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body()

  # return_type
  return_type = opts[:debug_return_type] || 'AccountBankModel'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2']

  new_options = opts.merge(
    :operation => :"AccountsBankApi.create_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountsBankApi#create_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_account(account_guid, opts = {}) ⇒ AccountBankModel

Get Account Retrieves an account. Required scope: accounts:read

Options Hash (opts):

  • :include_balances (Boolean)

    Whether to include account balances in the response.



96
97
98
99
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 96

def (, opts = {})
  data, _status_code, _headers = (, opts)
  data
end

#get_account_with_http_info(account_guid, opts = {}) ⇒ Array<(AccountBankModel, Integer, Hash)>

Get Account Retrieves an account. Required scope: accounts:read

Options Hash (opts):

  • :include_balances (Boolean)

    Whether to include account balances in the response.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 107

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountsBankApi.get_account ...'
  end
  # verify the required parameter 'account_guid' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_guid' when calling AccountsBankApi.get_account"
  end
  # resource path
  local_var_path = '/api/accounts/{account_guid}'.sub('{' + 'account_guid' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include_balances'] = opts[:'include_balances'] if !opts[:'include_balances'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AccountBankModel'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2']

  new_options = opts.merge(
    :operation => :"AccountsBankApi.get_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountsBankApi#get_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_accounts(opts = {}) ⇒ AccountListBankModel

List Accounts Retrieves a list of accounts. Records are sorted by creation date in descending order. Required scope: accounts:read

Options Hash (opts):

  • :page (Integer)

    The page index to retrieve.

  • :per_page (Integer)

    The number of entities per page to return.

  • :owner (String)

    The owner of the entity.

  • :guid (String)

    Comma separated account_guids to list accounts for.

  • :type (String)

    Comma separated account_types to list accounts for.

  • :bank_guid (String)

    Comma separated bank_guids to list accounts for.

  • :customer_guid (String)

    Comma separated customer_guids to list accounts for.

  • :label (String)

    Comma separated labels to list accounts for.

  • :include_balances (Boolean)

    Whether to include account balances in the response.



169
170
171
172
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 169

def list_accounts(opts = {})
  data, _status_code, _headers = list_accounts_with_http_info(opts)
  data
end

#list_accounts_with_http_info(opts = {}) ⇒ Array<(AccountListBankModel, Integer, Hash)>

List Accounts Retrieves a list of accounts. Records are sorted by creation date in descending order. Required scope: accounts:read

Options Hash (opts):

  • :page (Integer)

    The page index to retrieve.

  • :per_page (Integer)

    The number of entities per page to return.

  • :owner (String)

    The owner of the entity.

  • :guid (String)

    Comma separated account_guids to list accounts for.

  • :type (String)

    Comma separated account_types to list accounts for.

  • :bank_guid (String)

    Comma separated bank_guids to list accounts for.

  • :customer_guid (String)

    Comma separated customer_guids to list accounts for.

  • :label (String)

    Comma separated labels to list accounts for.

  • :include_balances (Boolean)

    Whether to include account balances in the response.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 187

def list_accounts_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountsBankApi.list_accounts ...'
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 0
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AccountsBankApi.list_accounts, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 100
    fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling AccountsBankApi.list_accounts, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling AccountsBankApi.list_accounts, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/api/accounts'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil?
  query_params[:'owner'] = opts[:'owner'] if !opts[:'owner'].nil?
  query_params[:'guid'] = opts[:'guid'] if !opts[:'guid'].nil?
  query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil?
  query_params[:'bank_guid'] = opts[:'bank_guid'] if !opts[:'bank_guid'].nil?
  query_params[:'customer_guid'] = opts[:'customer_guid'] if !opts[:'customer_guid'].nil?
  query_params[:'label'] = opts[:'label'] if !opts[:'label'].nil?
  query_params[:'include_balances'] = opts[:'include_balances'] if !opts[:'include_balances'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AccountListBankModel'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2']

  new_options = opts.merge(
    :operation => :"AccountsBankApi.list_accounts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountsBankApi#list_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_account(account_guid, patch_account_bank_model, opts = {}) ⇒ AccountBankModel

Patch Account Updates an account. Required scope: accounts:write



258
259
260
261
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 258

def (, , opts = {})
  data, _status_code, _headers = (, , opts)
  data
end

#update_account_with_http_info(account_guid, patch_account_bank_model, opts = {}) ⇒ Array<(AccountBankModel, Integer, Hash)>

Patch Account Updates an account. Required scope: accounts:write



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/cybrid_api_bank_ruby/api/accounts_bank_api.rb', line 269

def (, , opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AccountsBankApi.update_account ...'
  end
  # verify the required parameter 'account_guid' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_guid' when calling AccountsBankApi.update_account"
  end
  # verify the required parameter 'patch_account_bank_model' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'patch_account_bank_model' when calling AccountsBankApi.update_account"
  end
  # resource path
  local_var_path = '/api/accounts/{account_guid}'.sub('{' + 'account_guid' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body()

  # return_type
  return_type = opts[:debug_return_type] || 'AccountBankModel'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2']

  new_options = opts.merge(
    :operation => :"AccountsBankApi.update_account",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AccountsBankApi#update_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end