Class: CybridApiBank::BankBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/bank_bank_model.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BankBankModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::BankBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::BankBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'guid')
    self.guid = attributes[:'guid']
  else
    self.guid = nil
  end

  if attributes.key?(:'organization_guid')
    self.organization_guid = attributes[:'organization_guid']
  else
    self.organization_guid = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'supported_trading_symbols')
    if (value = attributes[:'supported_trading_symbols']).is_a?(Array)
      self.supported_trading_symbols = value
    end
  end

  if attributes.key?(:'supported_payout_symbols')
    if (value = attributes[:'supported_payout_symbols']).is_a?(Array)
      self.supported_payout_symbols = value
    end
  end

  if attributes.key?(:'supported_fiat_account_assets')
    if (value = attributes[:'supported_fiat_account_assets']).is_a?(Array)
      self. = value
    end
  end

  if attributes.key?(:'supported_country_codes')
    if (value = attributes[:'supported_country_codes']).is_a?(Array)
      self.supported_country_codes = value
    end
  end

  if attributes.key?(:'features')
    if (value = attributes[:'features']).is_a?(Array)
      self.features = value
    end
  else
    self.features = nil
  end

  if attributes.key?(:'cors_allowed_origins')
    if (value = attributes[:'cors_allowed_origins']).is_a?(Array)
      self.cors_allowed_origins = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#cors_allowed_originsObject

The bank's list of CORS allowed origins.



46
47
48
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 46

def cors_allowed_origins
  @cors_allowed_origins
end

#created_atObject

ISO8601 datetime the record was created at.



49
50
51
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 49

def created_at
  @created_at
end

#featuresObject

The bank's enabled features.



43
44
45
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 43

def features
  @features
end

#guidObject

Auto-generated unique identifier for the bank.



19
20
21
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 19

def guid
  @guid
end

#nameObject

The bank's name.



25
26
27
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 25

def name
  @name
end

#organization_guidObject

The organization's identifier.



22
23
24
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 22

def organization_guid
  @organization_guid
end

#supported_country_codesObject

The bank's list of supported country codes.



40
41
42
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 40

def supported_country_codes
  @supported_country_codes
end

#supported_fiat_account_assetsObject

The bank's list of supported fiat symbols.



37
38
39
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 37

def 
  @supported_fiat_account_assets
end

#supported_payout_symbolsObject

The bank's list of supported payout symbols.



34
35
36
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 34

def supported_payout_symbols
  @supported_payout_symbols
end

#supported_trading_symbolsObject

The bank's list of supported trading symbols.



31
32
33
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 31

def supported_trading_symbols
  @supported_trading_symbols
end

#typeObject

The bank type; one of sandbox or production.



28
29
30
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 28

def type
  @type
end

#updated_atObject

ISO8601 datetime the record was last updated at.



52
53
54
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 52

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 376

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 73

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 55

def self.attribute_map
  {
    :'guid' => :'guid',
    :'organization_guid' => :'organization_guid',
    :'name' => :'name',
    :'type' => :'type',
    :'supported_trading_symbols' => :'supported_trading_symbols',
    :'supported_payout_symbols' => :'supported_payout_symbols',
    :'supported_fiat_account_assets' => :'supported_fiat_account_assets',
    :'supported_country_codes' => :'supported_country_codes',
    :'features' => :'features',
    :'cors_allowed_origins' => :'cors_allowed_origins',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 352

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 78

def self.openapi_types
  {
    :'guid' => :'String',
    :'organization_guid' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'supported_trading_symbols' => :'Array<String>',
    :'supported_payout_symbols' => :'Array<BankSupportedPayoutSymbolsInnerBankModel>',
    :'supported_fiat_account_assets' => :'Array<String>',
    :'supported_country_codes' => :'Array<String>',
    :'features' => :'Array<String>',
    :'cors_allowed_origins' => :'Array<String>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 320

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      guid == o.guid &&
      organization_guid == o.organization_guid &&
      name == o.name &&
      type == o.type &&
      supported_trading_symbols == o.supported_trading_symbols &&
      supported_payout_symbols == o.supported_payout_symbols &&
       == o. &&
      supported_country_codes == o.supported_country_codes &&
      features == o.features &&
      cors_allowed_origins == o.cors_allowed_origins &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 447

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


339
340
341
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 339

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



345
346
347
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 345

def hash
  [guid, organization_guid, name, type, supported_trading_symbols, supported_payout_symbols, , supported_country_codes, features, cors_allowed_origins, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @guid.nil?
    invalid_properties.push('invalid value for "guid", guid cannot be nil.')
  end

  if @guid.to_s.length > 32
    invalid_properties.push('invalid value for "guid", the character length must be smaller than or equal to 32.')
  end

  if @guid.to_s.length < 32
    invalid_properties.push('invalid value for "guid", the character length must be great than or equal to 32.')
  end

  if @organization_guid.nil?
    invalid_properties.push('invalid value for "organization_guid", organization_guid cannot be nil.')
  end

  if @organization_guid.to_s.length > 32
    invalid_properties.push('invalid value for "organization_guid", the character length must be smaller than or equal to 32.')
  end

  if @organization_guid.to_s.length < 32
    invalid_properties.push('invalid value for "organization_guid", the character length must be great than or equal to 32.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @features.nil?
    invalid_properties.push('invalid value for "features", features cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



423
424
425
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 423

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 429

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



417
418
419
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 417

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/cybrid_api_bank_ruby/models/bank_bank_model.rb', line 247

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @guid.nil?
  return false if @guid.to_s.length > 32
  return false if @guid.to_s.length < 32
  return false if @organization_guid.nil?
  return false if @organization_guid.to_s.length > 32
  return false if @organization_guid.to_s.length < 32
  return false if @name.nil?
  return false if @name.to_s.length > 128
  return false if @name.to_s.length < 1
  return false if @type.nil?
  return false if @features.nil?
  return false if @created_at.nil?
  true
end