Class: CybridApiBank::DepositBankAccountBankModel
- Inherits:
-
Object
- Object
- CybridApiBank::DepositBankAccountBankModel
- Defined in:
- lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb
Instance Attribute Summary collapse
-
#account_details ⇒ Object
The account details for the bank account.
-
#account_guid ⇒ Object
The address' account identifier.
-
#asset ⇒ Object
The asset the transfer is related to, e.g., USD.
-
#bank_guid ⇒ Object
The address' bank identifier.
-
#counterparty_address ⇒ Object
Returns the value of attribute counterparty_address.
-
#counterparty_name ⇒ Object
The name of the account holder.
-
#created_at ⇒ Object
ISO8601 datetime the record was created at.
-
#customer_guid ⇒ Object
The address' customer identifier.
-
#deleted_at ⇒ Object
ISO8601 datetime the record was last deleted at.
-
#guid ⇒ Object
Auto-generated unique identifier for the identity verification.
-
#labels ⇒ Object
The labels associated with the address.
-
#name ⇒ Object
The name of the deposit bank account.
-
#parent_deposit_bank_account_guid ⇒ Object
The unique identifier for the bank-level deposit bank account.
-
#routing_details ⇒ Object
The account details for the bank account.
-
#state ⇒ Object
The state of the deposit bank account; one of storing, created, deleting, or deleted.
-
#type ⇒ Object
The account type; one of main or sub_account.
-
#unique_memo_id ⇒ Object
The unique memo identifier for the deposit bank account.
-
#updated_at ⇒ Object
ISO8601 datetime the record was last updated at.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DepositBankAccountBankModel
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DepositBankAccountBankModel
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::DepositBankAccountBankModel` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::DepositBankAccountBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'guid') self.guid = attributes[:'guid'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'bank_guid') self.bank_guid = attributes[:'bank_guid'] end if attributes.key?(:'customer_guid') self.customer_guid = attributes[:'customer_guid'] end if attributes.key?(:'account_guid') self.account_guid = attributes[:'account_guid'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'deleted_at') self.deleted_at = attributes[:'deleted_at'] end if attributes.key?(:'asset') self.asset = attributes[:'asset'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'unique_memo_id') self.unique_memo_id = attributes[:'unique_memo_id'] end if attributes.key?(:'counterparty_name') self.counterparty_name = attributes[:'counterparty_name'] end if attributes.key?(:'counterparty_address') self.counterparty_address = attributes[:'counterparty_address'] end if attributes.key?(:'account_details') if (value = attributes[:'account_details']).is_a?(Array) self.account_details = value end end if attributes.key?(:'routing_details') if (value = attributes[:'routing_details']).is_a?(Array) self.routing_details = value end end if attributes.key?(:'parent_deposit_bank_account_guid') self.parent_deposit_bank_account_guid = attributes[:'parent_deposit_bank_account_guid'] end if attributes.key?(:'labels') if (value = attributes[:'labels']).is_a?(Array) self.labels = value end end end |
Instance Attribute Details
#account_details ⇒ Object
The account details for the bank account.
60 61 62 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 60 def account_details @account_details end |
#account_guid ⇒ Object
The address' account identifier.
34 35 36 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 34 def account_guid @account_guid end |
#asset ⇒ Object
The asset the transfer is related to, e.g., USD.
46 47 48 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 46 def asset @asset end |
#bank_guid ⇒ Object
The address' bank identifier.
28 29 30 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 28 def bank_guid @bank_guid end |
#counterparty_address ⇒ Object
Returns the value of attribute counterparty_address.
57 58 59 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 57 def counterparty_address @counterparty_address end |
#counterparty_name ⇒ Object
The name of the account holder.
55 56 57 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 55 def counterparty_name @counterparty_name end |
#created_at ⇒ Object
ISO8601 datetime the record was created at.
37 38 39 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 37 def created_at @created_at end |
#customer_guid ⇒ Object
The address' customer identifier.
31 32 33 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 31 def customer_guid @customer_guid end |
#deleted_at ⇒ Object
ISO8601 datetime the record was last deleted at.
43 44 45 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 43 def deleted_at @deleted_at end |
#guid ⇒ Object
Auto-generated unique identifier for the identity verification.
19 20 21 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 19 def guid @guid end |
#labels ⇒ Object
The labels associated with the address.
69 70 71 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 69 def labels @labels end |
#name ⇒ Object
The name of the deposit bank account.
22 23 24 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 22 def name @name end |
#parent_deposit_bank_account_guid ⇒ Object
The unique identifier for the bank-level deposit bank account. This is only set for sub-accounts.
66 67 68 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 66 def parent_deposit_bank_account_guid @parent_deposit_bank_account_guid end |
#routing_details ⇒ Object
The account details for the bank account.
63 64 65 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 63 def routing_details @routing_details end |
#state ⇒ Object
The state of the deposit bank account; one of storing, created, deleting, or deleted.
49 50 51 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 49 def state @state end |
#type ⇒ Object
The account type; one of main or sub_account.
25 26 27 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 25 def type @type end |
#unique_memo_id ⇒ Object
The unique memo identifier for the deposit bank account. This is used to identify the recipient when sending funds to the account. This value MUST be included in all wire transfers to this account.
52 53 54 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 52 def unique_memo_id @unique_memo_id end |
#updated_at ⇒ Object
ISO8601 datetime the record was last updated at.
40 41 42 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 40 def updated_at @updated_at end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 96 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 72 def self.attribute_map { :'guid' => :'guid', :'name' => :'name', :'type' => :'type', :'bank_guid' => :'bank_guid', :'customer_guid' => :'customer_guid', :'account_guid' => :'account_guid', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'deleted_at' => :'deleted_at', :'asset' => :'asset', :'state' => :'state', :'unique_memo_id' => :'unique_memo_id', :'counterparty_name' => :'counterparty_name', :'counterparty_address' => :'counterparty_address', :'account_details' => :'account_details', :'routing_details' => :'routing_details', :'parent_deposit_bank_account_guid' => :'parent_deposit_bank_account_guid', :'labels' => :'labels' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
430 431 432 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 430 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 125 def self.openapi_nullable Set.new([ :'name', :'customer_guid', :'deleted_at', :'counterparty_name', :'counterparty_address', :'account_details', :'routing_details', :'parent_deposit_bank_account_guid', :'labels' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 101 def self.openapi_types { :'guid' => :'String', :'name' => :'String', :'type' => :'String', :'bank_guid' => :'String', :'customer_guid' => :'String', :'account_guid' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time', :'deleted_at' => :'Time', :'asset' => :'String', :'state' => :'String', :'unique_memo_id' => :'String', :'counterparty_name' => :'String', :'counterparty_address' => :'DepositBankAccountCounterpartyAddressBankModel', :'account_details' => :'Array<DepositBankAccountAccountDetailsInnerBankModel>', :'routing_details' => :'Array<DepositBankAccountRoutingDetailsInnerBankModel>', :'parent_deposit_bank_account_guid' => :'String', :'labels' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 392 def ==(o) return true if self.equal?(o) self.class == o.class && guid == o.guid && name == o.name && type == o.type && bank_guid == o.bank_guid && customer_guid == o.customer_guid && account_guid == o.account_guid && created_at == o.created_at && updated_at == o.updated_at && deleted_at == o.deleted_at && asset == o.asset && state == o.state && unique_memo_id == o.unique_memo_id && counterparty_name == o.counterparty_name && counterparty_address == o.counterparty_address && account_details == o.account_details && routing_details == o.routing_details && parent_deposit_bank_account_guid == o.parent_deposit_bank_account_guid && labels == o.labels end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 461 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CybridApiBank.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
532 533 534 535 536 537 538 539 540 541 542 543 544 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 532 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 437 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
417 418 419 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 417 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
423 424 425 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 423 def hash [guid, name, type, bank_guid, customer_guid, account_guid, created_at, updated_at, deleted_at, asset, state, unique_memo_id, counterparty_name, counterparty_address, account_details, routing_details, parent_deposit_bank_account_guid, labels].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 235 def list_invalid_properties invalid_properties = Array.new if !@guid.nil? && @guid.to_s.length > 32 invalid_properties.push('invalid value for "guid", the character length must be smaller than or equal to 32.') end if !@guid.nil? && @guid.to_s.length < 32 invalid_properties.push('invalid value for "guid", the character length must be great than or equal to 32.') end if !@name.nil? && @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if !@bank_guid.nil? && @bank_guid.to_s.length > 32 invalid_properties.push('invalid value for "bank_guid", the character length must be smaller than or equal to 32.') end if !@bank_guid.nil? && @bank_guid.to_s.length < 32 invalid_properties.push('invalid value for "bank_guid", the character length must be great than or equal to 32.') end if !@customer_guid.nil? && @customer_guid.to_s.length > 32 invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.') end if !@customer_guid.nil? && @customer_guid.to_s.length < 32 invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.') end if !@account_guid.nil? && @account_guid.to_s.length > 32 invalid_properties.push('invalid value for "account_guid", the character length must be smaller than or equal to 32.') end if !@account_guid.nil? && @account_guid.to_s.length < 32 invalid_properties.push('invalid value for "account_guid", the character length must be great than or equal to 32.') end if !@parent_deposit_bank_account_guid.nil? && @parent_deposit_bank_account_guid.to_s.length > 32 invalid_properties.push('invalid value for "parent_deposit_bank_account_guid", the character length must be smaller than or equal to 32.') end if !@parent_deposit_bank_account_guid.nil? && @parent_deposit_bank_account_guid.to_s.length < 32 invalid_properties.push('invalid value for "parent_deposit_bank_account_guid", the character length must be great than or equal to 32.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
508 509 510 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 508 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 514 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
502 503 504 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 502 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/cybrid_api_bank_ruby/models/deposit_bank_account_bank_model.rb', line 290 def valid? return false if !@guid.nil? && @guid.to_s.length > 32 return false if !@guid.nil? && @guid.to_s.length < 32 return false if !@name.nil? && @name.to_s.length > 128 return false if !@name.nil? && @name.to_s.length < 1 return false if !@bank_guid.nil? && @bank_guid.to_s.length > 32 return false if !@bank_guid.nil? && @bank_guid.to_s.length < 32 return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32 return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32 return false if !@account_guid.nil? && @account_guid.to_s.length > 32 return false if !@account_guid.nil? && @account_guid.to_s.length < 32 return false if !@parent_deposit_bank_account_guid.nil? && @parent_deposit_bank_account_guid.to_s.length > 32 return false if !@parent_deposit_bank_account_guid.nil? && @parent_deposit_bank_account_guid.to_s.length < 32 true end |