Class: CybridApiBank::ExecutionBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/execution_bank_model.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExecutionBankModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 169

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::ExecutionBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::ExecutionBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'guid')
    self.guid = attributes[:'guid']
  else
    self.guid = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'plan_guid')
    self.plan_guid = attributes[:'plan_guid']
  else
    self.plan_guid = nil
  end

  if attributes.key?(:'bank_guid')
    self.bank_guid = attributes[:'bank_guid']
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'failure_code')
    self.failure_code = attributes[:'failure_code']
  end

  if attributes.key?(:'source_account')
    self. = attributes[:'source_account']
  else
    self. = nil
  end

  if attributes.key?(:'destination_account')
    self. = attributes[:'destination_account']
  else
    self. = nil
  end

  if attributes.key?(:'intermediate_accounts')
    if (value = attributes[:'intermediate_accounts']).is_a?(Array)
      self.intermediate_accounts = value
    end
  end

  if attributes.key?(:'stages')
    if (value = attributes[:'stages']).is_a?(Array)
      self.stages = value
    end
  else
    self.stages = nil
  end

  if attributes.key?(:'fees')
    if (value = attributes[:'fees']).is_a?(Array)
      self.fees = value
    end
  else
    self.fees = nil
  end

  if attributes.key?(:'effective_rate')
    self.effective_rate = attributes[:'effective_rate']
  end

  if attributes.key?(:'holds')
    if (value = attributes[:'holds']).is_a?(Array)
      self.holds = value
    end
  end

  if attributes.key?(:'travel_rule_info')
    self.travel_rule_info = attributes[:'travel_rule_info']
  else
    self.travel_rule_info = nil
  end

  if attributes.key?(:'purpose_of_transaction')
    self.purpose_of_transaction = attributes[:'purpose_of_transaction']
  end

  if attributes.key?(:'references')
    if (value = attributes[:'references']).is_a?(Array)
      self.references = value
    end
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end
end

Instance Attribute Details

#bank_guidObject

The unique identifier for the bank.



28
29
30
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 28

def bank_guid
  @bank_guid
end

#created_atObject

ISO8601 datetime the record was created at.



34
35
36
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 34

def created_at
  @created_at
end

#customer_guidObject

The unique identifier for the customer.



31
32
33
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 31

def customer_guid
  @customer_guid
end

#destination_accountObject

Returns the value of attribute destination_account.



47
48
49
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 47

def 
  @destination_account
end

#effective_rateObject

Returns the value of attribute effective_rate.



58
59
60
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 58

def effective_rate
  @effective_rate
end

#failure_codeObject

The failure code for failed executions.



43
44
45
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 43

def failure_code
  @failure_code
end

#feesObject

The fees associated with the execution.



56
57
58
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 56

def fees
  @fees
end

#guidObject

Auto-generated unique identifier for the quote.



19
20
21
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 19

def guid
  @guid
end

#holdsObject

The holds placed on the execution.



61
62
63
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 61

def holds
  @holds
end

#intermediate_accountsObject

Intermediate accounts explicitly requested by the caller that were actually used to disambiguate the plan.



50
51
52
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 50

def intermediate_accounts
  @intermediate_accounts
end

#labelsObject

The labels associated with the execution.



72
73
74
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 72

def labels
  @labels
end

#plan_guidObject

The unique identifier for the plan.



25
26
27
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 25

def plan_guid
  @plan_guid
end

#purpose_of_transactionObject

The purpose of transaction for the execution.



66
67
68
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 66

def purpose_of_transaction
  @purpose_of_transaction
end

#referencesObject

Objects this return execution references (the returned execution and stage). Optional when type is deposit_return, type is withdrawal_return, or type is payout_return.



69
70
71
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 69

def references
  @references
end

#source_accountObject

Returns the value of attribute source_account.



45
46
47
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 45

def 
  @source_account
end

#stagesObject

The stages of the execution.



53
54
55
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 53

def stages
  @stages
end

#stateObject

The state of the execution; one of storing, executing, completed, failed, or reviewing.



40
41
42
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 40

def state
  @state
end

#travel_rule_infoObject

Returns the value of attribute travel_rule_info.



63
64
65
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 63

def travel_rule_info
  @travel_rule_info
end

#typeObject

The type of product the plan is for; one of remittance, bill_pay, disbursement, invoice_pay, deposit, withdrawal, conversion, deposit_return, withdrawal_return, or payout_return.



22
23
24
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 22

def type
  @type
end

#updated_atObject

ISO8601 datetime the record was last updated at.



37
38
39
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 37

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 549

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



123
124
125
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 123

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 97

def self.attribute_map
  {
    :'guid' => :'guid',
    :'type' => :'type',
    :'plan_guid' => :'plan_guid',
    :'bank_guid' => :'bank_guid',
    :'customer_guid' => :'customer_guid',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'state' => :'state',
    :'failure_code' => :'failure_code',
    :'source_account' => :'source_account',
    :'destination_account' => :'destination_account',
    :'intermediate_accounts' => :'intermediate_accounts',
    :'stages' => :'stages',
    :'fees' => :'fees',
    :'effective_rate' => :'effective_rate',
    :'holds' => :'holds',
    :'travel_rule_info' => :'travel_rule_info',
    :'purpose_of_transaction' => :'purpose_of_transaction',
    :'references' => :'references',
    :'labels' => :'labels'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 525

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 154

def self.openapi_nullable
  Set.new([
    :'bank_guid',
    :'customer_guid',
    :'failure_code',
    :'intermediate_accounts',
    :'holds',
    :'purpose_of_transaction',
    :'references',
    :'labels'
  ])
end

.openapi_typesObject

Attribute type mapping.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 128

def self.openapi_types
  {
    :'guid' => :'String',
    :'type' => :'String',
    :'plan_guid' => :'String',
    :'bank_guid' => :'String',
    :'customer_guid' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'state' => :'String',
    :'failure_code' => :'String',
    :'source_account' => :'AccountAssociationBankModel',
    :'destination_account' => :'AccountAssociationBankModel',
    :'intermediate_accounts' => :'Array<IntermediateAccountBankModel>',
    :'stages' => :'Array<StageBankModel>',
    :'fees' => :'Array<FeeAssociationBankModel>',
    :'effective_rate' => :'EffectiveRateBankModel',
    :'holds' => :'Array<HoldDetailBankModel>',
    :'travel_rule_info' => :'ExecutionTravelRuleInfoBankModel',
    :'purpose_of_transaction' => :'String',
    :'references' => :'Array<PlanReferenceBankModel>',
    :'labels' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 485

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      guid == o.guid &&
      type == o.type &&
      plan_guid == o.plan_guid &&
      bank_guid == o.bank_guid &&
      customer_guid == o.customer_guid &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      state == o.state &&
      failure_code == o.failure_code &&
       == o. &&
       == o. &&
      intermediate_accounts == o.intermediate_accounts &&
      stages == o.stages &&
      fees == o.fees &&
      effective_rate == o.effective_rate &&
      holds == o.holds &&
      travel_rule_info == o.travel_rule_info &&
      purpose_of_transaction == o.purpose_of_transaction &&
      references == o.references &&
      labels == o.labels
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



620
621
622
623
624
625
626
627
628
629
630
631
632
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 620

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


512
513
514
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 512

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



518
519
520
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 518

def hash
  [guid, type, plan_guid, bank_guid, customer_guid, created_at, updated_at, state, failure_code, , , intermediate_accounts, stages, fees, effective_rate, holds, travel_rule_info, purpose_of_transaction, references, labels].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 299

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @guid.nil?
    invalid_properties.push('invalid value for "guid", guid cannot be nil.')
  end

  if @guid.to_s.length > 32
    invalid_properties.push('invalid value for "guid", the character length must be smaller than or equal to 32.')
  end

  if @guid.to_s.length < 32
    invalid_properties.push('invalid value for "guid", the character length must be great than or equal to 32.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @plan_guid.nil?
    invalid_properties.push('invalid value for "plan_guid", plan_guid cannot be nil.')
  end

  if @plan_guid.to_s.length > 32
    invalid_properties.push('invalid value for "plan_guid", the character length must be smaller than or equal to 32.')
  end

  if @plan_guid.to_s.length < 32
    invalid_properties.push('invalid value for "plan_guid", the character length must be great than or equal to 32.')
  end

  if !@bank_guid.nil? && @bank_guid.to_s.length > 32
    invalid_properties.push('invalid value for "bank_guid", the character length must be smaller than or equal to 32.')
  end

  if !@bank_guid.nil? && @bank_guid.to_s.length < 32
    invalid_properties.push('invalid value for "bank_guid", the character length must be great than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @source_account.nil?
    invalid_properties.push('invalid value for "source_account", source_account cannot be nil.')
  end

  if @destination_account.nil?
    invalid_properties.push('invalid value for "destination_account", destination_account cannot be nil.')
  end

  if @stages.nil?
    invalid_properties.push('invalid value for "stages", stages cannot be nil.')
  end

  if @fees.nil?
    invalid_properties.push('invalid value for "fees", fees cannot be nil.')
  end

  if @travel_rule_info.nil?
    invalid_properties.push('invalid value for "travel_rule_info", travel_rule_info cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



596
597
598
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 596

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 602

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



590
591
592
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 590

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 383

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @guid.nil?
  return false if @guid.to_s.length > 32
  return false if @guid.to_s.length < 32
  return false if @type.nil?
  return false if @plan_guid.nil?
  return false if @plan_guid.to_s.length > 32
  return false if @plan_guid.to_s.length < 32
  return false if !@bank_guid.nil? && @bank_guid.to_s.length > 32
  return false if !@bank_guid.nil? && @bank_guid.to_s.length < 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @state.nil?
  return false if @source_account.nil?
  return false if @destination_account.nil?
  return false if @stages.nil?
  return false if @fees.nil?
  return false if @travel_rule_info.nil?
  purpose_of_transaction_validator = EnumAttributeValidator.new('String', ["computer_services", "family_support", "education", "gift", "charitable_donation", "medical_treatment", "maintenance_expenses", "travel", "hotel_accommodation", "small_value_remittance", "liberalized_remittance", "personal_transfer", "loan_payment", "tax_payment", "construction_expenses", "advertising_expenses", "advisory_fees", "business_insurance", "insurance_claims", "delivery_fees", "service_charges", "office_expenses", "property_purchase", "property_rental", "royalty_fees", "shares_investment", "fund_investment", "bill_payment", "transportation_fees", "salary_payment", "reward_payment", "influencer_payment", "other_fees", "other", "exported_goods", "commission_on_goods", "commission_on_services", "accounting_services", "exhibition_services"])
  return false unless purpose_of_transaction_validator.valid?(@purpose_of_transaction)
  true
end