Class: CybridApiBank::ExecutionsBankApi

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/api/executions_bank_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ExecutionsBankApi

Returns a new instance of ExecutionsBankApi.



19
20
21
# File 'lib/cybrid_api_bank_ruby/api/executions_bank_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/cybrid_api_bank_ruby/api/executions_bank_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_execution(post_execution_bank_model, opts = {}) ⇒ ExecutionBankModel

Create Execution Creates an execution. ## Create a plan execution | State | Description | |-------|-------------| | storing | The Platform is storing the execution details in our private store | | executing | The Platform is executing the plan | | completed | The Platform has successfully completed the plan execution | | failed | The Platform was not able to successfully complete the plan execution | ## Remittance failure codes | Code | Description | |------|-------------| | compliance_rejection | The payout was rejected due to a compliance or sanctions screening hit | | invalid_destination | The payout was rejected because the beneficiary details are invalid or not accepted by the payout partner | | party_name_invalid | The payout was rejected due to invalid sender or beneficiary name fields | | cancelled | The payout was cancelled | | reversed | The payout was reversed | | external_vendor_error | The payout failed due to vendor-side limits, transient unavailability, or duplicate detection | | market_volatility | The payout failed due to market volatility preventing quote execution | | no_quote | The payout failed because no valid payout quote was available | | internal_server_error | The payout failed due to an internal platform error | | invalid_quote_amount | The payout failed due to an invalid quote amount | | not_filled | The payout could not be filled | Required scope: executions:execute

Parameters:

  • post_execution_bank_model (PostExecutionBankModel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/cybrid_api_bank_ruby/api/executions_bank_api.rb', line 27

def create_execution(post_execution_bank_model, opts = {})
  data, _status_code, _headers = create_execution_with_http_info(post_execution_bank_model, opts)
  data
end

#create_execution_with_http_info(post_execution_bank_model, opts = {}) ⇒ Array<(ExecutionBankModel, Integer, Hash)>

Create Execution Creates an execution. ## Create a plan execution | State | Description | |-------|-------------| | storing | The Platform is storing the execution details in our private store | | executing | The Platform is executing the plan | | completed | The Platform has successfully completed the plan execution | | failed | The Platform was not able to successfully complete the plan execution | ## Remittance failure codes | Code | Description | |------|-------------| | compliance_rejection | The payout was rejected due to a compliance or sanctions screening hit | | invalid_destination | The payout was rejected because the beneficiary details are invalid or not accepted by the payout partner | | party_name_invalid | The payout was rejected due to invalid sender or beneficiary name fields | | cancelled | The payout was cancelled | | reversed | The payout was reversed | | external_vendor_error | The payout failed due to vendor-side limits, transient unavailability, or duplicate detection | | market_volatility | The payout failed due to market volatility preventing quote execution | | no_quote | The payout failed because no valid payout quote was available | | internal_server_error | The payout failed due to an internal platform error | | invalid_quote_amount | The payout failed due to an invalid quote amount | | not_filled | The payout could not be filled | Required scope: executions:execute

Parameters:

  • post_execution_bank_model (PostExecutionBankModel)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ExecutionBankModel, Integer, Hash)>)

    ExecutionBankModel data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/cybrid_api_bank_ruby/api/executions_bank_api.rb', line 37

def create_execution_with_http_info(post_execution_bank_model, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ExecutionsBankApi.create_execution ...'
  end
  # verify the required parameter 'post_execution_bank_model' is set
  if @api_client.config.client_side_validation && post_execution_bank_model.nil?
    fail ArgumentError, "Missing the required parameter 'post_execution_bank_model' when calling ExecutionsBankApi.create_execution"
  end
  # resource path
  local_var_path = '/api/executions'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(post_execution_bank_model)

  # return_type
  return_type = opts[:debug_return_type] || 'ExecutionBankModel'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2']

  new_options = opts.merge(
    :operation => :"ExecutionsBankApi.create_execution",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ExecutionsBankApi#create_execution\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_execution(execution_guid, opts = {}) ⇒ ExecutionBankModel

Get Execution Retrieves a execution. Required scope: executions:read

Parameters:

  • execution_guid (String)

    Identifier for the payment instruction.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



95
96
97
98
# File 'lib/cybrid_api_bank_ruby/api/executions_bank_api.rb', line 95

def get_execution(execution_guid, opts = {})
  data, _status_code, _headers = get_execution_with_http_info(execution_guid, opts)
  data
end

#get_execution_with_http_info(execution_guid, opts = {}) ⇒ Array<(ExecutionBankModel, Integer, Hash)>

Get Execution Retrieves a execution. Required scope: executions:read

Parameters:

  • execution_guid (String)

    Identifier for the payment instruction.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ExecutionBankModel, Integer, Hash)>)

    ExecutionBankModel data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/cybrid_api_bank_ruby/api/executions_bank_api.rb', line 105

def get_execution_with_http_info(execution_guid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ExecutionsBankApi.get_execution ...'
  end
  # verify the required parameter 'execution_guid' is set
  if @api_client.config.client_side_validation && execution_guid.nil?
    fail ArgumentError, "Missing the required parameter 'execution_guid' when calling ExecutionsBankApi.get_execution"
  end
  # resource path
  local_var_path = '/api/executions/{execution_guid}'.sub('{' + 'execution_guid' + '}', CGI.escape(execution_guid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ExecutionBankModel'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2']

  new_options = opts.merge(
    :operation => :"ExecutionsBankApi.get_execution",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ExecutionsBankApi#get_execution\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_executions(opts = {}) ⇒ ExecutionListBankModel

Get executions list Retrieves a listing of executions. Records are sorted by creation date in descending order. Required scope: executions:read

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    The page index to retrieve.

  • :per_page (Integer)

    The number of entities per page to return.

  • :guid (String)

    Comma separated execution_guids to list executions for.

  • :plan_guid (String)

    Comma separated plan_guids to list executions for.

  • :bank_guid (String)

    Comma separated bank_guids to list executions for.

  • :customer_guid (String)

    Comma separated customer_guids to list executions for.

  • :type (String)

    Comma separated types to list executions for.

  • :state (String)

    Comma separated states to list executions for.

  • :source_account_guid (String)

    Comma separated source account guids to list executions for.

  • :destination_account_guid (String)

    Comma separated destination account guids to list executions for.

  • :created_at_gte (String)

    Created at start date-time inclusive lower bound, ISO8601.

  • :created_at_lt (String)

    Created at end date-time exclusive upper bound, ISO8601.

  • :updated_at_gte (String)

    Updated at start date-time inclusive lower bound, ISO8601.

  • :updated_at_lt (String)

    Updated at end date-time exclusive upper bound, ISO8601.

Returns:



171
172
173
174
# File 'lib/cybrid_api_bank_ruby/api/executions_bank_api.rb', line 171

def list_executions(opts = {})
  data, _status_code, _headers = list_executions_with_http_info(opts)
  data
end

#list_executions_with_http_info(opts = {}) ⇒ Array<(ExecutionListBankModel, Integer, Hash)>

Get executions list Retrieves a listing of executions. Records are sorted by creation date in descending order. Required scope: executions:read

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    The page index to retrieve.

  • :per_page (Integer)

    The number of entities per page to return.

  • :guid (String)

    Comma separated execution_guids to list executions for.

  • :plan_guid (String)

    Comma separated plan_guids to list executions for.

  • :bank_guid (String)

    Comma separated bank_guids to list executions for.

  • :customer_guid (String)

    Comma separated customer_guids to list executions for.

  • :type (String)

    Comma separated types to list executions for.

  • :state (String)

    Comma separated states to list executions for.

  • :source_account_guid (String)

    Comma separated source account guids to list executions for.

  • :destination_account_guid (String)

    Comma separated destination account guids to list executions for.

  • :created_at_gte (String)

    Created at start date-time inclusive lower bound, ISO8601.

  • :created_at_lt (String)

    Created at end date-time exclusive upper bound, ISO8601.

  • :updated_at_gte (String)

    Updated at start date-time inclusive lower bound, ISO8601.

  • :updated_at_lt (String)

    Updated at end date-time exclusive upper bound, ISO8601.

Returns:

  • (Array<(ExecutionListBankModel, Integer, Hash)>)

    ExecutionListBankModel data, response status code and response headers



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/cybrid_api_bank_ruby/api/executions_bank_api.rb', line 194

def list_executions_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ExecutionsBankApi.list_executions ...'
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 0
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling ExecutionsBankApi.list_executions, must be greater than or equal to 0.'
  end

  if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 100
    fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling ExecutionsBankApi.list_executions, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling ExecutionsBankApi.list_executions, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/api/executions'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil?
  query_params[:'guid'] = opts[:'guid'] if !opts[:'guid'].nil?
  query_params[:'plan_guid'] = opts[:'plan_guid'] if !opts[:'plan_guid'].nil?
  query_params[:'bank_guid'] = opts[:'bank_guid'] if !opts[:'bank_guid'].nil?
  query_params[:'customer_guid'] = opts[:'customer_guid'] if !opts[:'customer_guid'].nil?
  query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil?
  query_params[:'state'] = opts[:'state'] if !opts[:'state'].nil?
  query_params[:'source_account_guid'] = opts[:'source_account_guid'] if !opts[:'source_account_guid'].nil?
  query_params[:'destination_account_guid'] = opts[:'destination_account_guid'] if !opts[:'destination_account_guid'].nil?
  query_params[:'created_at_gte'] = opts[:'created_at_gte'] if !opts[:'created_at_gte'].nil?
  query_params[:'created_at_lt'] = opts[:'created_at_lt'] if !opts[:'created_at_lt'].nil?
  query_params[:'updated_at_gte'] = opts[:'updated_at_gte'] if !opts[:'updated_at_gte'].nil?
  query_params[:'updated_at_lt'] = opts[:'updated_at_lt'] if !opts[:'updated_at_lt'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ExecutionListBankModel'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2']

  new_options = opts.merge(
    :operation => :"ExecutionsBankApi.list_executions",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ExecutionsBankApi#list_executions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end