Class: CybridApiBank::IdentityVerificationWithDetailsPiiBankModel
- Inherits:
-
Object
- Object
- CybridApiBank::IdentityVerificationWithDetailsPiiBankModel
- Defined in:
- lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb
Overview
The personally identifiable information associated with the identity verification.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#aliases ⇒ Object
The business attested aliases.
-
#business_funds_destination ⇒ Object
The attested business funds destination.
-
#business_funds_source ⇒ Object
The attested business funds source.
-
#business_incorporation_date ⇒ Object
The attested business incorporation date.
-
#business_industry ⇒ Object
The attested business industry.
-
#business_type ⇒ Object
The attested business type.
-
#citizenship ⇒ Object
The ISO 3166 country 2-Alpha country code of the customer's citizenship.
-
#date_of_birth ⇒ Object
The attested date of birth.
-
#email_address ⇒ Object
The attested email address.
-
#identification_numbers ⇒ Object
The attested identification numbers.
-
#name ⇒ Object
Returns the value of attribute name.
-
#nature_of_business ⇒ Object
The attested nature of business.
-
#occupation ⇒ Object
The attested occupation.
-
#phone_number ⇒ Object
The attested phone number.
-
#registered_address ⇒ Object
Returns the value of attribute registered_address.
-
#website ⇒ Object
The attested website.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityVerificationWithDetailsPiiBankModel
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IdentityVerificationWithDetailsPiiBankModel
Initializes the object
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 165 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::IdentityVerificationWithDetailsPiiBankModel` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::IdentityVerificationWithDetailsPiiBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'aliases') if (value = attributes[:'aliases']).is_a?(Array) self.aliases = value end end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] end if attributes.key?(:'occupation') self.occupation = attributes[:'occupation'] end if attributes.key?(:'citizenship') self.citizenship = attributes[:'citizenship'] end if attributes.key?(:'website') self.website = attributes[:'website'] end if attributes.key?(:'nature_of_business') self.nature_of_business = attributes[:'nature_of_business'] end if attributes.key?(:'registered_address') self.registered_address = attributes[:'registered_address'] end if attributes.key?(:'business_industry') self.business_industry = attributes[:'business_industry'] end if attributes.key?(:'business_funds_source') self.business_funds_source = attributes[:'business_funds_source'] end if attributes.key?(:'business_funds_destination') self.business_funds_destination = attributes[:'business_funds_destination'] end if attributes.key?(:'business_type') self.business_type = attributes[:'business_type'] end if attributes.key?(:'business_incorporation_date') self.business_incorporation_date = attributes[:'business_incorporation_date'] end if attributes.key?(:'identification_numbers') if (value = attributes[:'identification_numbers']).is_a?(Array) self.identification_numbers = value end end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
24 25 26 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 24 def address @address end |
#aliases ⇒ Object
The business attested aliases.
22 23 24 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 22 def aliases @aliases end |
#business_funds_destination ⇒ Object
The attested business funds destination.
56 57 58 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 56 def business_funds_destination @business_funds_destination end |
#business_funds_source ⇒ Object
The attested business funds source.
53 54 55 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 53 def business_funds_source @business_funds_source end |
#business_incorporation_date ⇒ Object
The attested business incorporation date.
62 63 64 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 62 def business_incorporation_date @business_incorporation_date end |
#business_industry ⇒ Object
The attested business industry.
50 51 52 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 50 def business_industry @business_industry end |
#business_type ⇒ Object
The attested business type.
59 60 61 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 59 def business_type @business_type end |
#citizenship ⇒ Object
The ISO 3166 country 2-Alpha country code of the customer's citizenship.
39 40 41 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 39 def citizenship @citizenship end |
#date_of_birth ⇒ Object
The attested date of birth.
27 28 29 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 27 def date_of_birth @date_of_birth end |
#email_address ⇒ Object
The attested email address.
33 34 35 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 33 def email_address @email_address end |
#identification_numbers ⇒ Object
The attested identification numbers.
65 66 67 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 65 def identification_numbers @identification_numbers end |
#name ⇒ Object
Returns the value of attribute name.
19 20 21 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 19 def name @name end |
#nature_of_business ⇒ Object
The attested nature of business.
45 46 47 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 45 def nature_of_business @nature_of_business end |
#occupation ⇒ Object
The attested occupation.
36 37 38 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 36 def occupation @occupation end |
#phone_number ⇒ Object
The attested phone number.
30 31 32 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 30 def phone_number @phone_number end |
#registered_address ⇒ Object
Returns the value of attribute registered_address.
47 48 49 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 47 def registered_address @registered_address end |
#website ⇒ Object
The attested website.
42 43 44 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 42 def website @website end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
113 114 115 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 113 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 90 def self.attribute_map { :'name' => :'name', :'aliases' => :'aliases', :'address' => :'address', :'date_of_birth' => :'date_of_birth', :'phone_number' => :'phone_number', :'email_address' => :'email_address', :'occupation' => :'occupation', :'citizenship' => :'citizenship', :'website' => :'website', :'nature_of_business' => :'nature_of_business', :'registered_address' => :'registered_address', :'business_industry' => :'business_industry', :'business_funds_source' => :'business_funds_source', :'business_funds_destination' => :'business_funds_destination', :'business_type' => :'business_type', :'business_incorporation_date' => :'business_incorporation_date', :'identification_numbers' => :'identification_numbers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
330 331 332 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 330 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 141 def self.openapi_nullable Set.new([ :'name', :'aliases', :'address', :'date_of_birth', :'phone_number', :'email_address', :'occupation', :'citizenship', :'website', :'nature_of_business', :'registered_address', :'business_industry', :'business_funds_source', :'business_funds_destination', :'business_type', :'business_incorporation_date', :'identification_numbers' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 118 def self.openapi_types { :'name' => :'IdentityVerificationWithDetailsPiiNameBankModel', :'aliases' => :'Array<IdentityVerificationWithDetailsPiiAliasesInnerBankModel>', :'address' => :'IdentityVerificationWithDetailsPiiAddressBankModel', :'date_of_birth' => :'Date', :'phone_number' => :'String', :'email_address' => :'String', :'occupation' => :'String', :'citizenship' => :'String', :'website' => :'String', :'nature_of_business' => :'String', :'registered_address' => :'IdentityVerificationWithDetailsPiiRegisteredAddressBankModel', :'business_industry' => :'String', :'business_funds_source' => :'String', :'business_funds_destination' => :'String', :'business_type' => :'String', :'business_incorporation_date' => :'Date', :'identification_numbers' => :'Array<IdentificationNumberBankModel>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 293 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && aliases == o.aliases && address == o.address && date_of_birth == o.date_of_birth && phone_number == o.phone_number && email_address == o.email_address && occupation == o.occupation && citizenship == o.citizenship && website == o.website && nature_of_business == o.nature_of_business && registered_address == o.registered_address && business_industry == o.business_industry && business_funds_source == o.business_funds_source && business_funds_destination == o.business_funds_destination && business_type == o.business_type && business_incorporation_date == o.business_incorporation_date && identification_numbers == o.identification_numbers end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 361 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CybridApiBank.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 432 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 337 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
317 318 319 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 317 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
323 324 325 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 323 def hash [name, aliases, address, date_of_birth, phone_number, email_address, occupation, citizenship, website, nature_of_business, registered_address, business_industry, business_funds_source, business_funds_destination, business_type, business_incorporation_date, identification_numbers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
253 254 255 256 257 258 259 260 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 253 def list_invalid_properties invalid_properties = Array.new if !@nature_of_business.nil? && @nature_of_business.to_s.length > 256 invalid_properties.push('invalid value for "nature_of_business", the character length must be smaller than or equal to 256.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
408 409 410 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 408 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 414 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
402 403 404 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 402 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
264 265 266 267 268 269 |
# File 'lib/cybrid_api_bank_ruby/models/identity_verification_with_details_pii_bank_model.rb', line 264 def valid? return false if !@nature_of_business.nil? && @nature_of_business.to_s.length > 256 business_type_validator = EnumAttributeValidator.new('String', ["entity", "sole_proprietor"]) return false unless business_type_validator.valid?(@business_type) true end |