Class: CybridApiBank::PostCounterpartyBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb

Overview

Request body for counterparty creation.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PostCounterpartyBankModel

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::PostCounterpartyBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::PostCounterpartyBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'aliases')
    if (value = attributes[:'aliases']).is_a?(Array)
      self.aliases = value
    end
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'identification_numbers')
    if (value = attributes[:'identification_numbers']).is_a?(Array)
      self.identification_numbers = value
    end
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



25
26
27
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 25

def address
  @address
end

#aliasesObject

The aliases of the counterparty. Optional when type is business.



30
31
32
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 30

def aliases
  @aliases
end

#customer_guidObject

The owning customer's identifier.



23
24
25
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 23

def customer_guid
  @customer_guid
end

#date_of_birthObject

The counterparty's date of birth. Optional when type is individual.



33
34
35
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 33

def date_of_birth
  @date_of_birth
end

#email_addressObject

The counterparty's email address.



36
37
38
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 36

def email_address
  @email_address
end

#identification_numbersObject

The counterparty's identification numbers.



39
40
41
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 39

def identification_numbers
  @identification_numbers
end

#labelsObject

The labels associated with the counterparty.



42
43
44
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 42

def labels
  @labels
end

#nameObject

Returns the value of attribute name.



27
28
29
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 27

def name
  @name
end

#typeObject

The counterparty's type.



20
21
22
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 20

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 355

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 67

def self.attribute_map
  {
    :'type' => :'type',
    :'customer_guid' => :'customer_guid',
    :'address' => :'address',
    :'name' => :'name',
    :'aliases' => :'aliases',
    :'date_of_birth' => :'date_of_birth',
    :'email_address' => :'email_address',
    :'identification_numbers' => :'identification_numbers',
    :'labels' => :'labels'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 331

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 102

def self.openapi_nullable
  Set.new([
    :'customer_guid',
    :'name',
    :'aliases',
    :'date_of_birth',
    :'email_address',
    :'identification_numbers',
    :'labels'
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 87

def self.openapi_types
  {
    :'type' => :'String',
    :'customer_guid' => :'String',
    :'address' => :'PostCounterpartyAddressBankModel',
    :'name' => :'PostCounterpartyNameBankModel',
    :'aliases' => :'Array<PostCounterpartyAliasesInnerBankModel>',
    :'date_of_birth' => :'Date',
    :'email_address' => :'String',
    :'identification_numbers' => :'Array<PostIdentificationNumberBankModel>',
    :'labels' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      customer_guid == o.customer_guid &&
      address == o.address &&
      name == o.name &&
      aliases == o.aliases &&
      date_of_birth == o.date_of_birth &&
      email_address == o.email_address &&
      identification_numbers == o.identification_numbers &&
      labels == o.labels
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 426

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • to be compared

Returns:



318
319
320
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 318

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



324
325
326
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 324

def hash
  [type, customer_guid, address, name, aliases, date_of_birth, email_address, identification_numbers, labels].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 178

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.')
  end

  if @address.nil?
    invalid_properties.push('invalid value for "address", address cannot be nil.')
  end

  if !@aliases.nil? && @aliases.length > 1
    invalid_properties.push('invalid value for "aliases", number of items must be less than or equal to 1.')
  end

  if !@aliases.nil? && @aliases.length < 0
    invalid_properties.push('invalid value for "aliases", number of items must be greater than or equal to 0.')
  end

  if !@identification_numbers.nil? && @identification_numbers.length > 10
    invalid_properties.push('invalid value for "identification_numbers", number of items must be less than or equal to 10.')
  end

  if !@identification_numbers.nil? && @identification_numbers.length < 1
    invalid_properties.push('invalid value for "identification_numbers", number of items must be greater than or equal to 1.')
  end

  if !@labels.nil? && @labels.length > 8
    invalid_properties.push('invalid value for "labels", number of items must be less than or equal to 8.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



402
403
404
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 402

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 408

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



396
397
398
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 396

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/cybrid_api_bank_ruby/models/post_counterparty_bank_model.rb', line 222

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["business", "individual"])
  return false unless type_validator.valid?(@type)
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32
  return false if @address.nil?
  return false if !@aliases.nil? && @aliases.length > 1
  return false if !@aliases.nil? && @aliases.length < 0
  return false if !@identification_numbers.nil? && @identification_numbers.length > 10
  return false if !@identification_numbers.nil? && @identification_numbers.length < 1
  return false if !@labels.nil? && @labels.length > 8
  true
end