Class: CybridApiBank::PostExternalBankAccountBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb

Overview

Request body for external bank account creation. The owner (the counterparty, or the customer when there is no counterparty) must already have a verified identity -- KYC for an individual, KYB for a business -- before an external bank account can be onboarded for them; the create is refused otherwise. Banks that verify individuals non-documentarily are the exception: an individual customer whose attested personal details have passed may onboard an account before verification completes, because the account is what authenticates them. 'plaid_processor_token' is not supported for this onboarding version.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PostExternalBankAccountBankModel

Initializes the object



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 158

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::PostExternalBankAccountBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::PostExternalBankAccountBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'account_kind')
    self. = attributes[:'account_kind']
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'asset')
    self.asset = attributes[:'asset']
  end

  if attributes.key?(:'plaid_public_token')
    self.plaid_public_token = attributes[:'plaid_public_token']
  end

  if attributes.key?(:'plaid_account_id')
    self. = attributes[:'plaid_account_id']
  end

  if attributes.key?(:'plaid_processor_token')
    self.plaid_processor_token = attributes[:'plaid_processor_token']
  end

  if attributes.key?(:'plaid_institution_id')
    self.plaid_institution_id = attributes[:'plaid_institution_id']
  end

  if attributes.key?(:'plaid_account_mask')
    self. = attributes[:'plaid_account_mask']
  end

  if attributes.key?(:'plaid_account_name')
    self. = attributes[:'plaid_account_name']
  end

  if attributes.key?(:'expected_behaviours')
    if (value = attributes[:'expected_behaviours']).is_a?(Array)
      self.expected_behaviours = value
    end
  end

  if attributes.key?(:'counterparty_guid')
    self.counterparty_guid = attributes[:'counterparty_guid']
  end

  if attributes.key?(:'counterparty_bank_account_details')
    if (value = attributes[:'counterparty_bank_account_details']).is_a?(Array)
      self. = value
    end
  end

  if attributes.key?(:'counterparty_name')
    self.counterparty_name = attributes[:'counterparty_name']
  end

  if attributes.key?(:'counterparty_address')
    self.counterparty_address = attributes[:'counterparty_address']
  end

  if attributes.key?(:'counterparty_email_address')
    self.counterparty_email_address = attributes[:'counterparty_email_address']
  end
end

Instance Attribute Details

#account_kindObject

The account type



23
24
25
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 23

def 
  @account_kind
end

#assetObject

The asset code. If not set will try and default to the Bank's configured fiat asset.



29
30
31
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 29

def asset
  @asset
end

#counterparty_addressObject

Returns the value of attribute counterparty_address.



60
61
62
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 60

def counterparty_address
  @counterparty_address
end

#counterparty_bank_account_detailsObject

The counterparty's checking bank account information. Required when account_kind is raw_routing_details.



56
57
58
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 56

def 
  
end

#counterparty_email_addressObject

The account holder's email address. Optional when account_kind is raw_routing_details.



63
64
65
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 63

def counterparty_email_address
  @counterparty_email_address
end

#counterparty_guidObject

The counterparty identifier. Optional when account_kind is raw_routing_details.



53
54
55
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 53

def counterparty_guid
  @counterparty_guid
end

#counterparty_nameObject

Returns the value of attribute counterparty_name.



58
59
60
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 58

def counterparty_name
  @counterparty_name
end

#customer_guidObject

The customer identifier.



26
27
28
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 26

def customer_guid
  @customer_guid
end

#expected_behavioursObject

Sandbox only: deterministically simulate the holder-name-match outcome instead of aligning the owner's KYC/KYB data with the linked account. Ignored for account kinds whose plan runs no holder-name match.



50
51
52
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 50

def expected_behaviours
  @expected_behaviours
end

#nameObject

The name of the account.



20
21
22
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 20

def name
  @name
end

#plaid_account_idObject

The account identifier in plaid. Required for 'plaid' accounts. Required when account_kind is plaid.



35
36
37
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 35

def 
  
end

#plaid_account_maskObject

The account mask for the account. Required when account_kind is plaid_processor_token.



44
45
46
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 44

def 
  
end

#plaid_account_nameObject

The name of the account. Required when account_kind is plaid_processor_token.



47
48
49
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 47

def 
  
end

#plaid_institution_idObject

Plaid's institution ID for the account's institution. Required when account_kind is plaid_processor_token.



41
42
43
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 41

def plaid_institution_id
  @plaid_institution_id
end

#plaid_processor_tokenObject

The Plaid processor token used to access the account. Required when account_kind is plaid_processor_token.



38
39
40
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 38

def plaid_processor_token
  @plaid_processor_token
end

#plaid_public_tokenObject

The public token for the account. Required for 'plaid' accounts. Required when account_kind is plaid.



32
33
34
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 32

def plaid_public_token
  @plaid_public_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 88

def self.attribute_map
  {
    :'name' => :'name',
    :'account_kind' => :'account_kind',
    :'customer_guid' => :'customer_guid',
    :'asset' => :'asset',
    :'plaid_public_token' => :'plaid_public_token',
    :'plaid_account_id' => :'plaid_account_id',
    :'plaid_processor_token' => :'plaid_processor_token',
    :'plaid_institution_id' => :'plaid_institution_id',
    :'plaid_account_mask' => :'plaid_account_mask',
    :'plaid_account_name' => :'plaid_account_name',
    :'expected_behaviours' => :'expected_behaviours',
    :'counterparty_guid' => :'counterparty_guid',
    :'counterparty_bank_account_details' => :'counterparty_bank_account_details',
    :'counterparty_name' => :'counterparty_name',
    :'counterparty_address' => :'counterparty_address',
    :'counterparty_email_address' => :'counterparty_email_address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



538
539
540
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 538

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 137

def self.openapi_nullable
  Set.new([
    :'customer_guid',
    :'asset',
    :'plaid_public_token',
    :'plaid_account_id',
    :'plaid_processor_token',
    :'plaid_institution_id',
    :'plaid_account_mask',
    :'plaid_account_name',
    :'expected_behaviours',
    :'counterparty_guid',
    :'counterparty_bank_account_details',
    :'counterparty_name',
    :'counterparty_address',
    :'counterparty_email_address'
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 115

def self.openapi_types
  {
    :'name' => :'String',
    :'account_kind' => :'String',
    :'customer_guid' => :'String',
    :'asset' => :'String',
    :'plaid_public_token' => :'String',
    :'plaid_account_id' => :'String',
    :'plaid_processor_token' => :'String',
    :'plaid_institution_id' => :'String',
    :'plaid_account_mask' => :'String',
    :'plaid_account_name' => :'String',
    :'expected_behaviours' => :'Array<String>',
    :'counterparty_guid' => :'String',
    :'counterparty_bank_account_details' => :'Array<PostBankAccountDetailsBankModel>',
    :'counterparty_name' => :'PostExternalBankAccountCounterpartyNameBankModel',
    :'counterparty_address' => :'PostExternalBankAccountCounterpartyAddressBankModel',
    :'counterparty_email_address' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 502

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
       == o. &&
      customer_guid == o.customer_guid &&
      asset == o.asset &&
      plaid_public_token == o.plaid_public_token &&
       == o. &&
      plaid_processor_token == o.plaid_processor_token &&
      plaid_institution_id == o.plaid_institution_id &&
       == o. &&
       == o. &&
      expected_behaviours == o.expected_behaviours &&
      counterparty_guid == o.counterparty_guid &&
       == o. &&
      counterparty_name == o.counterparty_name &&
      counterparty_address == o.counterparty_address &&
      counterparty_email_address == o.counterparty_email_address
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 569

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



640
641
642
643
644
645
646
647
648
649
650
651
652
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 640

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 545

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


525
526
527
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 525

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



531
532
533
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 531

def hash
  [name, , customer_guid, asset, plaid_public_token, , plaid_processor_token, plaid_institution_id, , , expected_behaviours, counterparty_guid, , counterparty_name, counterparty_address, counterparty_email_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 242

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @account_kind.nil?
    invalid_properties.push('invalid value for "account_kind", account_kind cannot be nil.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.')
  end

  if !@plaid_public_token.nil? && @plaid_public_token.to_s.length > 128
    invalid_properties.push('invalid value for "plaid_public_token", the character length must be smaller than or equal to 128.')
  end

  if !@plaid_public_token.nil? && @plaid_public_token.to_s.length < 1
    invalid_properties.push('invalid value for "plaid_public_token", the character length must be great than or equal to 1.')
  end

  if !.nil? && .to_s.length > 128
    invalid_properties.push('invalid value for "plaid_account_id", the character length must be smaller than or equal to 128.')
  end

  if !.nil? && .to_s.length < 1
    invalid_properties.push('invalid value for "plaid_account_id", the character length must be great than or equal to 1.')
  end

  if !@plaid_processor_token.nil? && @plaid_processor_token.to_s.length > 128
    invalid_properties.push('invalid value for "plaid_processor_token", the character length must be smaller than or equal to 128.')
  end

  if !@plaid_processor_token.nil? && @plaid_processor_token.to_s.length < 1
    invalid_properties.push('invalid value for "plaid_processor_token", the character length must be great than or equal to 1.')
  end

  if !@plaid_institution_id.nil? && @plaid_institution_id.to_s.length > 128
    invalid_properties.push('invalid value for "plaid_institution_id", the character length must be smaller than or equal to 128.')
  end

  if !@plaid_institution_id.nil? && @plaid_institution_id.to_s.length < 1
    invalid_properties.push('invalid value for "plaid_institution_id", the character length must be great than or equal to 1.')
  end

  if !.nil? && .to_s.length > 128
    invalid_properties.push('invalid value for "plaid_account_mask", the character length must be smaller than or equal to 128.')
  end

  if !.nil? && .to_s.length < 1
    invalid_properties.push('invalid value for "plaid_account_mask", the character length must be great than or equal to 1.')
  end

  if !.nil? && .to_s.length > 128
    invalid_properties.push('invalid value for "plaid_account_name", the character length must be smaller than or equal to 128.')
  end

  if !.nil? && .to_s.length < 1
    invalid_properties.push('invalid value for "plaid_account_name", the character length must be great than or equal to 1.')
  end

  if !@expected_behaviours.nil? && @expected_behaviours.length > 50
    invalid_properties.push('invalid value for "expected_behaviours", number of items must be less than or equal to 50.')
  end

  if !@counterparty_guid.nil? && @counterparty_guid.to_s.length > 32
    invalid_properties.push('invalid value for "counterparty_guid", the character length must be smaller than or equal to 32.')
  end

  if !@counterparty_guid.nil? && @counterparty_guid.to_s.length < 32
    invalid_properties.push('invalid value for "counterparty_guid", the character length must be great than or equal to 32.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



616
617
618
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 616

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 622

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



610
611
612
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 610

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/cybrid_api_bank_ruby/models/post_external_bank_account_bank_model.rb', line 333

def valid?
  return false if @name.nil?
  return false if @name.to_s.length > 128
  return false if @name.to_s.length < 1
  return false if @account_kind.nil?
   = EnumAttributeValidator.new('String', ["plaid", "plaid_processor_token", "raw_routing_details"])
  return false unless .valid?(@account_kind)
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32
  return false if !@plaid_public_token.nil? && @plaid_public_token.to_s.length > 128
  return false if !@plaid_public_token.nil? && @plaid_public_token.to_s.length < 1
  return false if !.nil? && .to_s.length > 128
  return false if !.nil? && .to_s.length < 1
  return false if !@plaid_processor_token.nil? && @plaid_processor_token.to_s.length > 128
  return false if !@plaid_processor_token.nil? && @plaid_processor_token.to_s.length < 1
  return false if !@plaid_institution_id.nil? && @plaid_institution_id.to_s.length > 128
  return false if !@plaid_institution_id.nil? && @plaid_institution_id.to_s.length < 1
  return false if !.nil? && .to_s.length > 128
  return false if !.nil? && .to_s.length < 1
  return false if !.nil? && .to_s.length > 128
  return false if !.nil? && .to_s.length < 1
  return false if !@expected_behaviours.nil? && @expected_behaviours.length > 50
  return false if !@counterparty_guid.nil? && @counterparty_guid.to_s.length > 32
  return false if !@counterparty_guid.nil? && @counterparty_guid.to_s.length < 32
  true
end