Class: CybridApiBank::PostExternalWalletBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb

Overview

Request body for external wallet creation.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PostExternalWalletBankModel

Initializes the object



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::PostExternalWalletBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::PostExternalWalletBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'counterparty_guid')
    self.counterparty_guid = attributes[:'counterparty_guid']
  end

  if attributes.key?(:'asset')
    self.asset = attributes[:'asset']
  else
    self.asset = nil
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'expected_behaviours')
    if (value = attributes[:'expected_behaviours']).is_a?(Array)
      self.expected_behaviours = value
    end
  end
end

Instance Attribute Details

#addressObject

The blockchain wallet address for the wallet.



32
33
34
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 32

def address
  @address
end

#assetObject

The asset code.



29
30
31
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 29

def asset
  @asset
end

#counterparty_guidObject

The counterparty identifier.



26
27
28
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 26

def counterparty_guid
  @counterparty_guid
end

#customer_guidObject

The customer identifier.



23
24
25
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 23

def customer_guid
  @customer_guid
end

#expected_behavioursObject

The optional expected behaviour to simulate. Only applicable wallets under sandbox banks.



38
39
40
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 38

def expected_behaviours
  @expected_behaviours
end

#nameObject

Name of the external wallet.



20
21
22
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 20

def name
  @name
end

#tagObject

The blockchain tag to use when transferring crypto to the wallet.



35
36
37
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 35

def tag
  @tag
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 381

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 76

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 63

def self.attribute_map
  {
    :'name' => :'name',
    :'customer_guid' => :'customer_guid',
    :'counterparty_guid' => :'counterparty_guid',
    :'asset' => :'asset',
    :'address' => :'address',
    :'tag' => :'tag',
    :'expected_behaviours' => :'expected_behaviours'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 357

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
99
100
101
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 94

def self.openapi_nullable
  Set.new([
    :'customer_guid',
    :'counterparty_guid',
    :'tag',
    :'expected_behaviours'
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 81

def self.openapi_types
  {
    :'name' => :'String',
    :'customer_guid' => :'String',
    :'counterparty_guid' => :'String',
    :'asset' => :'String',
    :'address' => :'String',
    :'tag' => :'String',
    :'expected_behaviours' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



330
331
332
333
334
335
336
337
338
339
340
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 330

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      customer_guid == o.customer_guid &&
      counterparty_guid == o.counterparty_guid &&
      asset == o.asset &&
      address == o.address &&
      tag == o.tag &&
      expected_behaviours == o.expected_behaviours
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 452

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


344
345
346
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 344

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



350
351
352
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 350

def hash
  [name, customer_guid, counterparty_guid, asset, address, tag, expected_behaviours].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.')
  end

  if !@counterparty_guid.nil? && @counterparty_guid.to_s.length > 32
    invalid_properties.push('invalid value for "counterparty_guid", the character length must be smaller than or equal to 32.')
  end

  if !@counterparty_guid.nil? && @counterparty_guid.to_s.length < 32
    invalid_properties.push('invalid value for "counterparty_guid", the character length must be great than or equal to 32.')
  end

  if @asset.nil?
    invalid_properties.push('invalid value for "asset", asset cannot be nil.')
  end

  if @asset.to_s.length > 16
    invalid_properties.push('invalid value for "asset", the character length must be smaller than or equal to 16.')
  end

  if @asset.to_s.length < 1
    invalid_properties.push('invalid value for "asset", the character length must be great than or equal to 1.')
  end

  if @address.nil?
    invalid_properties.push('invalid value for "address", address cannot be nil.')
  end

  if @address.to_s.length > 1024
    invalid_properties.push('invalid value for "address", the character length must be smaller than or equal to 1024.')
  end

  if !@tag.nil? && @tag.to_s.length > 512
    invalid_properties.push('invalid value for "tag", the character length must be smaller than or equal to 512.')
  end

  if !@expected_behaviours.nil? && @expected_behaviours.length > 50
    invalid_properties.push('invalid value for "expected_behaviours", number of items must be less than or equal to 50.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



428
429
430
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 428

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 434

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



422
423
424
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 422

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/cybrid_api_bank_ruby/models/post_external_wallet_bank_model.rb', line 221

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 128
  return false if @name.to_s.length < 1
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32
  return false if !@counterparty_guid.nil? && @counterparty_guid.to_s.length > 32
  return false if !@counterparty_guid.nil? && @counterparty_guid.to_s.length < 32
  return false if @asset.nil?
  return false if @asset.to_s.length > 16
  return false if @asset.to_s.length < 1
  return false if @address.nil?
  return false if @address.to_s.length > 1024
  return false if !@tag.nil? && @tag.to_s.length > 512
  return false if !@expected_behaviours.nil? && @expected_behaviours.length > 50
  true
end