Class: CybridApiBank::PostInvoiceBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb

Overview

Request body for invoice creation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PostInvoiceBankModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::PostInvoiceBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::PostInvoiceBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'asset')
    self.asset = attributes[:'asset']
  else
    self.asset = nil
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'receive_amount')
    self.receive_amount = attributes[:'receive_amount']
  end

  if attributes.key?(:'deliver_amount')
    self.deliver_amount = attributes[:'deliver_amount']
  end

  if attributes.key?(:'account_guid')
    self. = attributes[:'account_guid']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end
end

Instance Attribute Details

#account_guidObject

The identifier for the account to use for the transfer. Required if the customer has multiple fiat accounts. Currently only valid for invoices paid to a fiat account.



32
33
34
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 32

def 
  @account_guid
end

#assetObject

The asset code the customer will receive the funds in.



20
21
22
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 20

def asset
  @asset
end

#customer_guidObject

The unique identifier for the customer.



23
24
25
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 23

def customer_guid
  @customer_guid
end

#deliver_amountObject

The amount to be delivered in base units of the asset, i.e., the amount the customer will receive before fees. ONLY one of receive_amount or deliver_amount is required.



29
30
31
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 29

def deliver_amount
  @deliver_amount
end

#labelsObject

The labels associated with the invoice.



35
36
37
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 35

def labels
  @labels
end

#receive_amountObject

The amount to be received in base units of the asset, i.e., the amount the customer will receive after fees. ONLY one of receive_amount or deliver_amount is required.



26
27
28
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 26

def receive_amount
  @receive_amount
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 282

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 50

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 38

def self.attribute_map
  {
    :'asset' => :'asset',
    :'customer_guid' => :'customer_guid',
    :'receive_amount' => :'receive_amount',
    :'deliver_amount' => :'deliver_amount',
    :'account_guid' => :'account_guid',
    :'labels' => :'labels'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
72
73
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 67

def self.openapi_nullable
  Set.new([
    :'customer_guid',
    :'account_guid',
    :'labels'
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 55

def self.openapi_types
  {
    :'asset' => :'String',
    :'customer_guid' => :'String',
    :'receive_amount' => :'Integer',
    :'deliver_amount' => :'Integer',
    :'account_guid' => :'String',
    :'labels' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
241
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      asset == o.asset &&
      customer_guid == o.customer_guid &&
      receive_amount == o.receive_amount &&
      deliver_amount == o.deliver_amount &&
       == o. &&
      labels == o.labels
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 353

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 251

def hash
  [asset, customer_guid, receive_amount, deliver_amount, , labels].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @asset.nil?
    invalid_properties.push('invalid value for "asset", asset cannot be nil.')
  end

  if @asset.to_s.length > 16
    invalid_properties.push('invalid value for "asset", the character length must be smaller than or equal to 16.')
  end

  if @asset.to_s.length < 1
    invalid_properties.push('invalid value for "asset", the character length must be great than or equal to 1.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.')
  end

  if !@account_guid.nil? && @account_guid.to_s.length > 32
    invalid_properties.push('invalid value for "account_guid", the character length must be smaller than or equal to 32.')
  end

  if !@account_guid.nil? && @account_guid.to_s.length < 32
    invalid_properties.push('invalid value for "account_guid", the character length must be great than or equal to 32.')
  end

  if !@labels.nil? && @labels.length > 8
    invalid_properties.push('invalid value for "labels", number of items must be less than or equal to 8.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 329

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 335

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



323
324
325
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 323

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/cybrid_api_bank_ruby/models/post_invoice_bank_model.rb', line 161

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @asset.nil?
  return false if @asset.to_s.length > 16
  return false if @asset.to_s.length < 1
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32
  return false if !@account_guid.nil? && @account_guid.to_s.length > 32
  return false if !@account_guid.nil? && @account_guid.to_s.length < 32
  return false if !@labels.nil? && @labels.length > 8
  true
end