Class: CybridApiBank::PostPlanBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb

Overview

Request body for plan creation.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PostPlanBankModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::PostPlanBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::PostPlanBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'bank_guid')
    self.bank_guid = attributes[:'bank_guid']
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'source_account')
    self. = attributes[:'source_account']
  end

  if attributes.key?(:'destination_account')
    self. = attributes[:'destination_account']
  end

  if attributes.key?(:'intermediate_accounts')
    if (value = attributes[:'intermediate_accounts']).is_a?(Array)
      self.intermediate_accounts = value
    end
  end

  if attributes.key?(:'travel_rule_info')
    self.travel_rule_info = attributes[:'travel_rule_info']
  end

  if attributes.key?(:'purpose_of_transaction')
    self.purpose_of_transaction = attributes[:'purpose_of_transaction']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end

  if attributes.key?(:'supporting_documents')
    if (value = attributes[:'supporting_documents']).is_a?(Array)
      self.supporting_documents = value
    end
  end
end

Instance Attribute Details

#bank_guidObject

The unique identifier for the bank.



23
24
25
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 23

def bank_guid
  @bank_guid
end

#customer_guidObject

The unique identifier for the customer.



26
27
28
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 26

def customer_guid
  @customer_guid
end

#destination_accountObject

Returns the value of attribute destination_account.



30
31
32
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 30

def 
  
end

#intermediate_accountsObject

Accounts to disambiguate a multi-stage plan when more than one account of the same asset is eligible for a stage.



33
34
35
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 33

def intermediate_accounts
  @intermediate_accounts
end

#labelsObject

The labels associated with the plan.



41
42
43
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 41

def labels
  @labels
end

#purpose_of_transactionObject

The purpose of transaction for the plan.



38
39
40
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 38

def purpose_of_transaction
  @purpose_of_transaction
end

#source_accountObject

Returns the value of attribute source_account.



28
29
30
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 28

def 
  
end

#supporting_documentsObject

Supporting documents to attach to the plan. Optional when type is remittance or type is invoice_pay.



44
45
46
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 44

def supporting_documents
  @supporting_documents
end

#travel_rule_infoObject

Returns the value of attribute travel_rule_info.



35
36
37
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 35

def travel_rule_info
  @travel_rule_info
end

#typeObject

The type of product the plan is for.



20
21
22
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 85

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 69

def self.attribute_map
  {
    :'type' => :'type',
    :'bank_guid' => :'bank_guid',
    :'customer_guid' => :'customer_guid',
    :'source_account' => :'source_account',
    :'destination_account' => :'destination_account',
    :'intermediate_accounts' => :'intermediate_accounts',
    :'travel_rule_info' => :'travel_rule_info',
    :'purpose_of_transaction' => :'purpose_of_transaction',
    :'labels' => :'labels',
    :'supporting_documents' => :'supporting_documents'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 342

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 106

def self.openapi_nullable
  Set.new([
    :'bank_guid',
    :'customer_guid',
    :'intermediate_accounts',
    :'travel_rule_info',
    :'purpose_of_transaction',
    :'labels',
    :'supporting_documents'
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 90

def self.openapi_types
  {
    :'type' => :'String',
    :'bank_guid' => :'String',
    :'customer_guid' => :'String',
    :'source_account' => :'PostPlanSourceAccountBankModel',
    :'destination_account' => :'PostPlanDestinationAccountBankModel',
    :'intermediate_accounts' => :'Array<PostPlanIntermediateAccountsInnerBankModel>',
    :'travel_rule_info' => :'PostPlanTravelRuleInfoBankModel',
    :'purpose_of_transaction' => :'String',
    :'labels' => :'Array<String>',
    :'supporting_documents' => :'Array<PostSupportingDocumentBankModel>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 312

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      bank_guid == o.bank_guid &&
      customer_guid == o.customer_guid &&
       == o. &&
       == o. &&
      intermediate_accounts == o.intermediate_accounts &&
      travel_rule_info == o.travel_rule_info &&
      purpose_of_transaction == o.purpose_of_transaction &&
      labels == o.labels &&
      supporting_documents == o.supporting_documents
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 373

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 444

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 349

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


329
330
331
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 329

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



335
336
337
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 335

def hash
  [type, bank_guid, customer_guid, , , intermediate_accounts, travel_rule_info, purpose_of_transaction, labels, supporting_documents].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 182

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@bank_guid.nil? && @bank_guid.to_s.length > 32
    invalid_properties.push('invalid value for "bank_guid", the character length must be smaller than or equal to 32.')
  end

  if !@bank_guid.nil? && @bank_guid.to_s.length < 32
    invalid_properties.push('invalid value for "bank_guid", the character length must be great than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.')
  end

  if .nil?
    invalid_properties.push('invalid value for "source_account", source_account cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "destination_account", destination_account cannot be nil.')
  end

  if !@labels.nil? && @labels.length > 8
    invalid_properties.push('invalid value for "labels", number of items must be less than or equal to 8.')
  end

  if !@supporting_documents.nil? && @supporting_documents.length > 3
    invalid_properties.push('invalid value for "supporting_documents", number of items must be less than or equal to 3.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



420
421
422
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 420

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 426

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



414
415
416
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 414

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/cybrid_api_bank_ruby/models/post_plan_bank_model.rb', line 225

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["remittance", "bill_pay", "disbursement", "invoice_pay", "deposit", "withdrawal", "conversion"])
  return false unless type_validator.valid?(@type)
  return false if !@bank_guid.nil? && @bank_guid.to_s.length > 32
  return false if !@bank_guid.nil? && @bank_guid.to_s.length < 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32
  return false if .nil?
  return false if .nil?
  purpose_of_transaction_validator = EnumAttributeValidator.new('String', ["computer_services", "family_support", "education", "gift", "charitable_donation", "medical_treatment", "maintenance_expenses", "travel", "hotel_accommodation", "small_value_remittance", "liberalized_remittance", "personal_transfer", "loan_payment", "tax_payment", "construction_expenses", "advertising_expenses", "advisory_fees", "business_insurance", "insurance_claims", "delivery_fees", "service_charges", "office_expenses", "property_purchase", "property_rental", "royalty_fees", "shares_investment", "fund_investment", "bill_payment", "transportation_fees", "salary_payment", "reward_payment", "influencer_payment", "other_fees", "other", "exported_goods", "commission_on_goods", "commission_on_services", "accounting_services", "exhibition_services"])
  return false unless purpose_of_transaction_validator.valid?(@purpose_of_transaction)
  return false if !@labels.nil? && @labels.length > 8
  return false if !@supporting_documents.nil? && @supporting_documents.length > 3
  true
end