Class: CybridApiBank::StageBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/stage_bank_model.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StageBankModel

Initializes the object



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::StageBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::StageBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'guid')
    self.guid = attributes[:'guid']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'failure_code')
    self.failure_code = attributes[:'failure_code']
  end

  if attributes.key?(:'identifiers')
    if (value = attributes[:'identifiers']).is_a?(Array)
      self.identifiers = value
    end
  end

  if attributes.key?(:'links')
    if (value = attributes[:'links']).is_a?(Array)
      self.links = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'source_account')
    self. = attributes[:'source_account']
  end

  if attributes.key?(:'destination_account')
    self. = attributes[:'destination_account']
  end

  if attributes.key?(:'fees')
    if (value = attributes[:'fees']).is_a?(Array)
      self.fees = value
    end
  end

  if attributes.key?(:'effective_rate')
    self.effective_rate = attributes[:'effective_rate']
  end

  if attributes.key?(:'deposit_return_details')
    self.deposit_return_details = attributes[:'deposit_return_details']
  end

  if attributes.key?(:'withdrawal_return_details')
    self.withdrawal_return_details = attributes[:'withdrawal_return_details']
  end

  if attributes.key?(:'payout_return_details')
    self.payout_return_details = attributes[:'payout_return_details']
  end
end

Instance Attribute Details

#created_atObject

The ISO8601 datetime the stage was created at.



37
38
39
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 37

def created_at
  @created_at
end

#deposit_return_detailsObject

Returns the value of attribute deposit_return_details.



51
52
53
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 51

def deposit_return_details
  @deposit_return_details
end

#destination_accountObject

Returns the value of attribute destination_account.



44
45
46
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 44

def 
  
end

#effective_rateObject

Returns the value of attribute effective_rate.



49
50
51
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 49

def effective_rate
  @effective_rate
end

#failure_codeObject

The failure code for failed stages.



28
29
30
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 28

def failure_code
  @failure_code
end

#feesObject

The fees associated with the stage.



47
48
49
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 47

def fees
  @fees
end

#guidObject

The unique identifier for the stage.



19
20
21
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 19

def guid
  @guid
end

#identifiersObject

Provider-issued identifiers associated with this stage. Always present, possibly empty.



31
32
33
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 31

def identifiers
  @identifiers
end

Provider-issued links associated with this stage. Always present, possibly empty.



34
35
36
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 34

def links
  @links
end

#payout_return_detailsObject

Returns the value of attribute payout_return_details.



55
56
57
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 55

def payout_return_details
  @payout_return_details
end

#source_accountObject

Returns the value of attribute source_account.



42
43
44
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 42

def 
  
end

#stateObject

The state of the stage; one of storing, planning, planned, executing, completed, or failed.



25
26
27
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 25

def state
  @state
end

#typeObject

The type of stage; one of payout, deposit, withdrawal, trade, deposit_return, loss_recovery, withdrawal_return, or payout_return.



22
23
24
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 22

def type
  @type
end

#updated_atObject

The ISO8601 datetime the stage was last updated at.



40
41
42
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 40

def updated_at
  @updated_at
end

#withdrawal_return_detailsObject

Returns the value of attribute withdrawal_return_details.



53
54
55
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 53

def withdrawal_return_details
  @withdrawal_return_details
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 79

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 58

def self.attribute_map
  {
    :'guid' => :'guid',
    :'type' => :'type',
    :'state' => :'state',
    :'failure_code' => :'failure_code',
    :'identifiers' => :'identifiers',
    :'links' => :'links',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'source_account' => :'source_account',
    :'destination_account' => :'destination_account',
    :'fees' => :'fees',
    :'effective_rate' => :'effective_rate',
    :'deposit_return_details' => :'deposit_return_details',
    :'withdrawal_return_details' => :'withdrawal_return_details',
    :'payout_return_details' => :'payout_return_details'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



321
322
323
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 321

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
109
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 105

def self.openapi_nullable
  Set.new([
    :'failure_code',
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 84

def self.openapi_types
  {
    :'guid' => :'String',
    :'type' => :'String',
    :'state' => :'String',
    :'failure_code' => :'String',
    :'identifiers' => :'Array<StageIdentifierBankModel>',
    :'links' => :'Array<StageLinkBankModel>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'source_account' => :'AccountAssociationBankModel',
    :'destination_account' => :'AccountAssociationBankModel',
    :'fees' => :'Array<FeeAssociationBankModel>',
    :'effective_rate' => :'EffectiveRateBankModel',
    :'deposit_return_details' => :'ReturnDetailsBankModel',
    :'withdrawal_return_details' => :'ReturnDetailsBankModel',
    :'payout_return_details' => :'PayoutReturnDetailsBankModel'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 286

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      guid == o.guid &&
      type == o.type &&
      state == o.state &&
      failure_code == o.failure_code &&
      identifiers == o.identifiers &&
      links == o.links &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
       == o. &&
       == o. &&
      fees == o.fees &&
      effective_rate == o.effective_rate &&
      deposit_return_details == o.deposit_return_details &&
      withdrawal_return_details == o.withdrawal_return_details &&
      payout_return_details == o.payout_return_details
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 352

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 423

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 328

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


308
309
310
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 308

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



314
315
316
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 314

def hash
  [guid, type, state, failure_code, identifiers, links, created_at, updated_at, , , fees, effective_rate, deposit_return_details, withdrawal_return_details, payout_return_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 195

def list_invalid_properties
  invalid_properties = Array.new
  if @guid.nil?
    invalid_properties.push('invalid value for "guid", guid cannot be nil.')
  end

  if @guid.to_s.length > 32
    invalid_properties.push('invalid value for "guid", the character length must be smaller than or equal to 32.')
  end

  if @guid.to_s.length < 32
    invalid_properties.push('invalid value for "guid", the character length must be great than or equal to 32.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @identifiers.nil?
    invalid_properties.push('invalid value for "identifiers", identifiers cannot be nil.')
  end

  if @links.nil?
    invalid_properties.push('invalid value for "links", links cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "source_account", source_account cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "destination_account", destination_account cannot be nil.')
  end

  if @fees.nil?
    invalid_properties.push('invalid value for "fees", fees cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



399
400
401
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 399

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 405

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



393
394
395
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 393

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/cybrid_api_bank_ruby/models/stage_bank_model.rb', line 250

def valid?
  return false if @guid.nil?
  return false if @guid.to_s.length > 32
  return false if @guid.to_s.length < 32
  return false if @type.nil?
  return false if @state.nil?
  return false if @identifiers.nil?
  return false if @links.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if .nil?
  return false if .nil?
  return false if @fees.nil?
  true
end