Class: CybridApiBank::ExecutionBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/execution_bank_model.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExecutionBankModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::ExecutionBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::ExecutionBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'guid')
    self.guid = attributes[:'guid']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'plan_guid')
    self.plan_guid = attributes[:'plan_guid']
  end

  if attributes.key?(:'bank_guid')
    self.bank_guid = attributes[:'bank_guid']
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'failure_code')
    self.failure_code = attributes[:'failure_code']
  end

  if attributes.key?(:'source_account')
    self. = attributes[:'source_account']
  end

  if attributes.key?(:'destination_account')
    self. = attributes[:'destination_account']
  end

  if attributes.key?(:'stages')
    if (value = attributes[:'stages']).is_a?(Array)
      self.stages = value
    end
  end

  if attributes.key?(:'fees')
    if (value = attributes[:'fees']).is_a?(Array)
      self.fees = value
    end
  end

  if attributes.key?(:'travel_rule_info')
    self.travel_rule_info = attributes[:'travel_rule_info']
  end

  if attributes.key?(:'purpose_of_transaction')
    self.purpose_of_transaction = attributes[:'purpose_of_transaction']
  end
end

Instance Attribute Details

#bank_guidObject

The unique identifier for the bank.



29
30
31
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 29

def bank_guid
  @bank_guid
end

#created_atObject

ISO8601 datetime the record was created at.



35
36
37
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 35

def created_at
  @created_at
end

#customer_guidObject

The unique identifier for the customer.



32
33
34
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 32

def customer_guid
  @customer_guid
end

#destination_accountObject

Returns the value of attribute destination_account.



48
49
50
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 48

def 
  
end

#failure_codeObject

The failure code for failed executions.



44
45
46
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 44

def failure_code
  @failure_code
end

#feesObject

The fees associated with the execution.



54
55
56
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 54

def fees
  @fees
end

#guidObject

Auto-generated unique identifier for the quote.



20
21
22
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 20

def guid
  @guid
end

#plan_guidObject

The unique identifier for the plan.



26
27
28
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 26

def plan_guid
  @plan_guid
end

#purpose_of_transactionObject

The purpose of transaction for the execution.



59
60
61
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 59

def purpose_of_transaction
  @purpose_of_transaction
end

#source_accountObject

Returns the value of attribute source_account.



46
47
48
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 46

def 
  
end

#stagesObject

The stages of the execution.



51
52
53
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 51

def stages
  @stages
end

#stateObject

The state of the execution; one of storing, executing, completed, or failed.



41
42
43
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 41

def state
  @state
end

#travel_rule_infoObject

Returns the value of attribute travel_rule_info.



56
57
58
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 56

def travel_rule_info
  @travel_rule_info
end

#typeObject

The type of product the plan is for; one of remittance.



23
24
25
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 23

def type
  @type
end

#updated_atObject

ISO8601 datetime the record was last updated at.



38
39
40
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 38

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



105
106
107
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 105

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 84

def self.attribute_map
  {
    :'guid' => :'guid',
    :'type' => :'type',
    :'plan_guid' => :'plan_guid',
    :'bank_guid' => :'bank_guid',
    :'customer_guid' => :'customer_guid',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'state' => :'state',
    :'failure_code' => :'failure_code',
    :'source_account' => :'source_account',
    :'destination_account' => :'destination_account',
    :'stages' => :'stages',
    :'fees' => :'fees',
    :'travel_rule_info' => :'travel_rule_info',
    :'purpose_of_transaction' => :'purpose_of_transaction'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



441
442
443
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 441

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



131
132
133
134
135
136
137
138
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 131

def self.openapi_nullable
  Set.new([
    :'bank_guid',
    :'customer_guid',
    :'failure_code',
    :'purpose_of_transaction'
  ])
end

.openapi_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 110

def self.openapi_types
  {
    :'guid' => :'String',
    :'type' => :'String',
    :'plan_guid' => :'String',
    :'bank_guid' => :'String',
    :'customer_guid' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'state' => :'String',
    :'failure_code' => :'String',
    :'source_account' => :'AccountAssociationBankModel',
    :'destination_account' => :'AccountAssociationBankModel',
    :'stages' => :'Array<StageBankModel>',
    :'fees' => :'Array<FeeAssociationBankModel>',
    :'travel_rule_info' => :'ExecutionTravelRuleInfoBankModel',
    :'purpose_of_transaction' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 406

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      guid == o.guid &&
      type == o.type &&
      plan_guid == o.plan_guid &&
      bank_guid == o.bank_guid &&
      customer_guid == o.customer_guid &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      state == o.state &&
      failure_code == o.failure_code &&
       == o. &&
       == o. &&
      stages == o.stages &&
      fees == o.fees &&
      travel_rule_info == o.travel_rule_info &&
      purpose_of_transaction == o.purpose_of_transaction
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 472

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



543
544
545
546
547
548
549
550
551
552
553
554
555
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 543

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 448

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


428
429
430
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 428

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



434
435
436
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 434

def hash
  [guid, type, plan_guid, bank_guid, customer_guid, created_at, updated_at, state, failure_code, , , stages, fees, travel_rule_info, purpose_of_transaction].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 222

def list_invalid_properties
  invalid_properties = Array.new
  if @guid.nil?
    invalid_properties.push('invalid value for "guid", guid cannot be nil.')
  end

  if @guid.to_s.length > 32
    invalid_properties.push('invalid value for "guid", the character length must be smaller than or equal to 32.')
  end

  if @guid.to_s.length < 32
    invalid_properties.push('invalid value for "guid", the character length must be great than or equal to 32.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @plan_guid.nil?
    invalid_properties.push('invalid value for "plan_guid", plan_guid cannot be nil.')
  end

  if @plan_guid.to_s.length > 32
    invalid_properties.push('invalid value for "plan_guid", the character length must be smaller than or equal to 32.')
  end

  if @plan_guid.to_s.length < 32
    invalid_properties.push('invalid value for "plan_guid", the character length must be great than or equal to 32.')
  end

  if !@bank_guid.nil? && @bank_guid.to_s.length > 32
    invalid_properties.push('invalid value for "bank_guid", the character length must be smaller than or equal to 32.')
  end

  if !@bank_guid.nil? && @bank_guid.to_s.length < 32
    invalid_properties.push('invalid value for "bank_guid", the character length must be great than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "source_account", source_account cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "destination_account", destination_account cannot be nil.')
  end

  if @stages.nil?
    invalid_properties.push('invalid value for "stages", stages cannot be nil.')
  end

  if @fees.nil?
    invalid_properties.push('invalid value for "fees", fees cannot be nil.')
  end

  if @travel_rule_info.nil?
    invalid_properties.push('invalid value for "travel_rule_info", travel_rule_info cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



519
520
521
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 519

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



525
526
527
528
529
530
531
532
533
534
535
536
537
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 525

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



513
514
515
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 513

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/cybrid_api_bank_ruby/models/execution_bank_model.rb', line 305

def valid?
  return false if @guid.nil?
  return false if @guid.to_s.length > 32
  return false if @guid.to_s.length < 32
  return false if @type.nil?
  return false if @plan_guid.nil?
  return false if @plan_guid.to_s.length > 32
  return false if @plan_guid.to_s.length < 32
  return false if !@bank_guid.nil? && @bank_guid.to_s.length > 32
  return false if !@bank_guid.nil? && @bank_guid.to_s.length < 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @state.nil?
  return false if .nil?
  return false if .nil?
  return false if @stages.nil?
  return false if @fees.nil?
  return false if @travel_rule_info.nil?
  purpose_of_transaction_validator = EnumAttributeValidator.new('String', ["computer_services", "family_support", "education", "gift", "charitable_donation", "medical_treatment", "maintenance_expenses", "travel", "hotel_accommodation", "small_value_remittance", "liberalized_remittance", "personal_transfer", "loan_payment", "tax_payment", "construction_expenses", "advertising_expenses", "advisory_fees", "business_insurance", "insurance_claims", "delivery_fees", "service_charges", "office_expenses", "property_purchase", "property_rental", "royalty_fees", "shares_investment", "fund_investment", "bill_payment", "transportation_fees", "salary_payment", "reward_payment", "influencer_payment", "other_fees", "other"])
  return false unless purpose_of_transaction_validator.valid?(@purpose_of_transaction)
  true
end