Class: CybridApiBank::PlansBankApi
- Inherits:
-
Object
- Object
- CybridApiBank::PlansBankApi
- Defined in:
- lib/cybrid_api_bank_ruby/api/plans_bank_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_plan(post_plan_bank_model, opts = {}) ⇒ PlanBankModel
Create Plan Creates a plan.
-
#create_plan_with_http_info(post_plan_bank_model, opts = {}) ⇒ Array<(PlanBankModel, Integer, Hash)>
Create Plan Creates a plan.
-
#get_plan(plan_guid, opts = {}) ⇒ PlanBankModel
Get Plan Retrieves a plan.
-
#get_plan_with_http_info(plan_guid, opts = {}) ⇒ Array<(PlanBankModel, Integer, Hash)>
Get Plan Retrieves a plan.
-
#initialize(api_client = ApiClient.default) ⇒ PlansBankApi
constructor
A new instance of PlansBankApi.
-
#list_plans(opts = {}) ⇒ PlanListBankModel
Get plans list Retrieves a listing of plans.
-
#list_plans_with_http_info(opts = {}) ⇒ Array<(PlanListBankModel, Integer, Hash)>
Get plans list Retrieves a listing of plans.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PlansBankApi
Returns a new instance of PlansBankApi.
19 20 21 |
# File 'lib/cybrid_api_bank_ruby/api/plans_bank_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cybrid_api_bank_ruby/api/plans_bank_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_plan(post_plan_bank_model, opts = {}) ⇒ PlanBankModel
Create Plan
Creates a plan. ## Create a plan Plans can be created for a Bank or a Customer. To create plan for your Bank, omit the customer_guid parameter in the request body. To create plans for your Customers, include the customer_guid parameter in the request body. | State | Description | |-------|-------------| | storing | The Platform is storing the plan details in our private store | | planning | The Platform is currently building the plan | | completed | The Platform has successfully completed the plan | | failed | The Platform was not able to successfully complete the plan | Required scope: plans:execute
27 28 29 30 |
# File 'lib/cybrid_api_bank_ruby/api/plans_bank_api.rb', line 27 def create_plan(post_plan_bank_model, opts = {}) data, _status_code, _headers = create_plan_with_http_info(post_plan_bank_model, opts) data end |
#create_plan_with_http_info(post_plan_bank_model, opts = {}) ⇒ Array<(PlanBankModel, Integer, Hash)>
Create Plan Creates a plan. ## Create a plan Plans can be created for a Bank or a Customer. To create plan for your Bank, omit the `customer_guid` parameter in the request body. To create plans for your Customers, include the `customer_guid` parameter in the request body. | State | Description | |-------|-------------| | storing | The Platform is storing the plan details in our private store | | planning | The Platform is currently building the plan | | completed | The Platform has successfully completed the plan | | failed | The Platform was not able to successfully complete the plan | Required scope: plans:execute
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/cybrid_api_bank_ruby/api/plans_bank_api.rb', line 37 def create_plan_with_http_info(post_plan_bank_model, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlansBankApi.create_plan ...' end # verify the required parameter 'post_plan_bank_model' is set if @api_client.config.client_side_validation && post_plan_bank_model.nil? fail ArgumentError, "Missing the required parameter 'post_plan_bank_model' when calling PlansBankApi.create_plan" end # resource path local_var_path = '/api/plans' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(post_plan_bank_model) # return_type return_type = opts[:debug_return_type] || 'PlanBankModel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2'] = opts.merge( :operation => :"PlansBankApi.create_plan", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlansBankApi#create_plan\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_plan(plan_guid, opts = {}) ⇒ PlanBankModel
Get Plan Retrieves a plan. Required scope: plans:read
95 96 97 98 |
# File 'lib/cybrid_api_bank_ruby/api/plans_bank_api.rb', line 95 def get_plan(plan_guid, opts = {}) data, _status_code, _headers = get_plan_with_http_info(plan_guid, opts) data end |
#get_plan_with_http_info(plan_guid, opts = {}) ⇒ Array<(PlanBankModel, Integer, Hash)>
Get Plan Retrieves a plan. Required scope: plans:read
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/cybrid_api_bank_ruby/api/plans_bank_api.rb', line 105 def get_plan_with_http_info(plan_guid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlansBankApi.get_plan ...' end # verify the required parameter 'plan_guid' is set if @api_client.config.client_side_validation && plan_guid.nil? fail ArgumentError, "Missing the required parameter 'plan_guid' when calling PlansBankApi.get_plan" end # resource path local_var_path = '/api/plans/{plan_guid}'.sub('{' + 'plan_guid' + '}', CGI.escape(plan_guid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlanBankModel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2'] = opts.merge( :operation => :"PlansBankApi.get_plan", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlansBankApi#get_plan\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_plans(opts = {}) ⇒ PlanListBankModel
Get plans list Retrieves a listing of plans. Records are sorted by creation date in descending order. Required scope: plans:read
171 172 173 174 |
# File 'lib/cybrid_api_bank_ruby/api/plans_bank_api.rb', line 171 def list_plans(opts = {}) data, _status_code, _headers = list_plans_with_http_info(opts) data end |
#list_plans_with_http_info(opts = {}) ⇒ Array<(PlanListBankModel, Integer, Hash)>
Get plans list Retrieves a listing of plans. Records are sorted by creation date in descending order. Required scope: plans:read
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/cybrid_api_bank_ruby/api/plans_bank_api.rb', line 194 def list_plans_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlansBankApi.list_plans ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 0 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling PlansBankApi.list_plans, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 100 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling PlansBankApi.list_plans, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling PlansBankApi.list_plans, must be greater than or equal to 1.' end # resource path local_var_path = '/api/plans' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'guid'] = opts[:'guid'] if !opts[:'guid'].nil? query_params[:'bank_guid'] = opts[:'bank_guid'] if !opts[:'bank_guid'].nil? query_params[:'customer_guid'] = opts[:'customer_guid'] if !opts[:'customer_guid'].nil? query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil? query_params[:'state'] = opts[:'state'] if !opts[:'state'].nil? query_params[:'source_account_guid'] = opts[:'source_account_guid'] if !opts[:'source_account_guid'].nil? query_params[:'destination_account_guid'] = opts[:'destination_account_guid'] if !opts[:'destination_account_guid'].nil? query_params[:'created_at_gte'] = opts[:'created_at_gte'] if !opts[:'created_at_gte'].nil? query_params[:'created_at_lt'] = opts[:'created_at_lt'] if !opts[:'created_at_lt'].nil? query_params[:'updated_at_gte'] = opts[:'updated_at_gte'] if !opts[:'updated_at_gte'].nil? query_params[:'updated_at_lt'] = opts[:'updated_at_lt'] if !opts[:'updated_at_lt'].nil? query_params[:'label'] = opts[:'label'] if !opts[:'label'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlanListBankModel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2'] = opts.merge( :operation => :"PlansBankApi.list_plans", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlansBankApi#list_plans\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |