Class: CybridApiBank::PostBankAccountDetailsBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb

Overview

Bank account details.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PostBankAccountDetailsBankModel

Initializes the object



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::PostBankAccountDetailsBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::PostBankAccountDetailsBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bank_code')
    self.bank_code = attributes[:'bank_code']
  end

  if attributes.key?(:'account_identifier')
    self. = attributes[:'account_identifier']
  end

  if attributes.key?(:'account_identifier_type')
    self. = attributes[:'account_identifier_type']
  end

  if attributes.key?(:'payment_rail')
    self.payment_rail = attributes[:'payment_rail']
  end

  if attributes.key?(:'bank_code_type')
    self.bank_code_type = attributes[:'bank_code_type']
  end

  if attributes.key?(:'account_type')
    self. = attributes[:'account_type']
  end

  if attributes.key?(:'account_designation')
    self. = attributes[:'account_designation']
  end
end

Instance Attribute Details

#account_designationObject

Account designation for India IFSC and UPI accounts (NRE or NRO). Defaults to NRE when omitted. Optional when payment_rail is IFSC or payment_rail is UPI.



38
39
40
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 38

def 
  @account_designation
end

#account_identifierObject

The account number or unique identifier for the account.



23
24
25
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 23

def 
  @account_identifier
end

#account_identifier_typeObject

The type of account identifier. Must be VPA for UPI rails and PHONE_NUMBER for mobile wallet rails. Required when payment_rail is UPI, payment_rail is EASY_PAISA, payment_rail is FINJA, payment_rail is JAZZ_CASH, payment_rail is NAYA_PAY, payment_rail is SADA_PAY, payment_rail is MPESA, or payment_rail is ALIPAY.



26
27
28
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 26

def 
  @account_identifier_type
end

#account_typeObject

The type of account. Required when payment_rail is PSE or payment_rail is LBTR. Optional when payment_rail is ACH or payment_rail is WIRE.



35
36
37
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 35

def 
  @account_type
end

#bank_codeObject

The bank code.



20
21
22
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 20

def bank_code
  @bank_code
end

#bank_code_typeObject

The type of bank code. Required when payment_rail is EFT, payment_rail is ACH, payment_rail is RTP, payment_rail is FEDNOW, payment_rail is WIRE, payment_rail is SPEI, payment_rail is PIX, payment_rail is COELSA, payment_rail is PSE, payment_rail is ETRANSFER, payment_rail is IFSC, payment_rail is SBP, payment_rail is BEFTN, payment_rail is NGBANK, payment_rail is LBTR, payment_rail is SEPA, payment_rail is KEBANK, payment_rail is HKBANK, payment_rail is CNBANK, payment_rail is FPS, or payment_rail is UNSPECIFIED.



32
33
34
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 32

def bank_code_type
  @bank_code_type
end

#payment_railObject

The payment rail used for the account.



29
30
31
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 29

def payment_rail
  @payment_rail
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 76

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 63

def self.attribute_map
  {
    :'bank_code' => :'bank_code',
    :'account_identifier' => :'account_identifier',
    :'account_identifier_type' => :'account_identifier_type',
    :'payment_rail' => :'payment_rail',
    :'bank_code_type' => :'bank_code_type',
    :'account_type' => :'account_type',
    :'account_designation' => :'account_designation'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



260
261
262
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 260

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
99
100
101
102
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 94

def self.openapi_nullable
  Set.new([
    :'bank_code',
    :'account_identifier_type',
    :'bank_code_type',
    :'account_type',
    :'account_designation'
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 81

def self.openapi_types
  {
    :'bank_code' => :'String',
    :'account_identifier' => :'String',
    :'account_identifier_type' => :'String',
    :'payment_rail' => :'String',
    :'bank_code_type' => :'String',
    :'account_type' => :'String',
    :'account_designation' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



233
234
235
236
237
238
239
240
241
242
243
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 233

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bank_code == o.bank_code &&
       == o. &&
       == o. &&
      payment_rail == o.payment_rail &&
      bank_code_type == o.bank_code_type &&
       == o. &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 291

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 362

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 267

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


247
248
249
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



253
254
255
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 253

def hash
  [bank_code, , , payment_rail, bank_code_type, , ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 150

def list_invalid_properties
  invalid_properties = Array.new
  if @account_identifier.nil?
    invalid_properties.push('invalid value for "account_identifier", account_identifier cannot be nil.')
  end

  if @payment_rail.nil?
    invalid_properties.push('invalid value for "payment_rail", payment_rail cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



338
339
340
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 338

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 344

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



332
333
334
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 332

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/cybrid_api_bank_ruby/models/post_bank_account_details_bank_model.rb', line 165

def valid?
  return false if @account_identifier.nil?
   = EnumAttributeValidator.new('String', ["CLABE", "PHONE_NUMBER", "EMAIL", "DEBIT_CARD", "CBU", "CVU", "RANDOM", "CPF", "CNPJ", "VPA"])
  return false unless .valid?(@account_identifier_type)
  return false if @payment_rail.nil?
  payment_rail_validator = EnumAttributeValidator.new('String', ["EFT", "ACH", "RTP", "FEDNOW", "WIRE", "SPEI", "PIX", "COELSA", "PSE", "ETRANSFER", "IFSC", "UPI", "SBP", "BEFTN", "NGBANK", "LBTR", "SEPA", "EASY_PAISA", "FINJA", "JAZZ_CASH", "NAYA_PAY", "SADA_PAY", "KEBANK", "HKBANK", "MPESA", "CNBANK", "FPS", "ALIPAY", "UNSPECIFIED"])
  return false unless payment_rail_validator.valid?(@payment_rail)
  bank_code_type_validator = EnumAttributeValidator.new('String', ["CPA", "ABA", "CLABE", "PIX", "CBU_CVU", "PSE", "IFSC", "IBAN", "SBP", "BEFTN", "SWIFT_BIC", "CBN", "SORT_CODE"])
  return false unless bank_code_type_validator.valid?(@bank_code_type)
   = EnumAttributeValidator.new('String', ["checking", "savings"])
  return false unless .valid?(@account_type)
   = EnumAttributeValidator.new('String', ["NRE", "NRO"])
  return false unless .valid?(@account_designation)
  true
end