Class: CybridApiBank::PostIdentityVerificationBankModel
- Inherits:
-
Object
- Object
- CybridApiBank::PostIdentityVerificationBankModel
- Defined in:
- lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb
Overview
Request body for identity verification creation.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#aliases ⇒ Object
The aliases of the customer.
-
#biometrics_verified ⇒ Object
Whether biometrics have been verified Required when type is kyc and method is attested_business_associate or type is kyc and method is attested_id_and_database.
-
#business_funds_destination ⇒ Object
The destination of business funds.
-
#business_funds_source ⇒ Object
The source of business funds.
-
#business_incorporation_date ⇒ Object
The date the business was incorporated.
-
#business_industry ⇒ Object
The industry the business operates in.
-
#business_type ⇒ Object
The type of business.
-
#citizenship ⇒ Object
The customer's citizenship country code.
-
#counterparty_guid ⇒ Object
The counterparty's identifier.
-
#country_code ⇒ Object
The ISO 3166 country 2-Alpha country the customer is being verified in.
-
#customer_guid ⇒ Object
The customer's identifier.
-
#date_of_birth ⇒ Object
The customer's date of birth.
-
#director_customer_guids ⇒ Object
The customer guids of the directors of the business Required when type is kyc and method is attested_business_registration.
-
#email_address ⇒ Object
The customer's email address.
-
#expected_behaviours ⇒ Object
The optional expected behaviour to simulate.
-
#external_bank_account_guid ⇒ Object
The external bank account's identifier.
-
#identification_numbers ⇒ Object
The customer's identification numbers.
-
#method ⇒ Object
The identity verification method.
-
#name ⇒ Object
Returns the value of attribute name.
-
#nature_of_business ⇒ Object
The customer's nature of business.
-
#occupation ⇒ Object
The customer's occupation.
-
#phone_number ⇒ Object
The customer's phone number.
-
#registered_address ⇒ Object
Returns the value of attribute registered_address.
-
#require_tax_id ⇒ Object
Whether the collection of the tax id is required during identity verification.
-
#supporting_file_guids ⇒ Object
File guids supporting the verification Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_business_associate, or type is kyc and method is attested_id_and_database.
-
#type ⇒ Object
The type of identity verification.
-
#ultimate_beneficial_owners ⇒ Object
The ultimate beneficial owners of the business with 25% or more ownership.
-
#website ⇒ Object
The customer's website.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostIdentityVerificationBankModel
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PostIdentityVerificationBankModel
Initializes the object
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 236 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::PostIdentityVerificationBankModel` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::PostIdentityVerificationBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'customer_guid') self.customer_guid = attributes[:'customer_guid'] end if attributes.key?(:'expected_behaviours') if (value = attributes[:'expected_behaviours']).is_a?(Array) self.expected_behaviours = value end end if attributes.key?(:'method') self.method = attributes[:'method'] end if attributes.key?(:'counterparty_guid') self.counterparty_guid = attributes[:'counterparty_guid'] end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] end if attributes.key?(:'require_tax_id') self.require_tax_id = attributes[:'require_tax_id'] else self.require_tax_id = false end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'identification_numbers') if (value = attributes[:'identification_numbers']).is_a?(Array) self.identification_numbers = value end end if attributes.key?(:'aliases') if (value = attributes[:'aliases']).is_a?(Array) self.aliases = value end end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] end if attributes.key?(:'website') self.website = attributes[:'website'] end if attributes.key?(:'nature_of_business') self.nature_of_business = attributes[:'nature_of_business'] end if attributes.key?(:'director_customer_guids') if (value = attributes[:'director_customer_guids']).is_a?(Array) self.director_customer_guids = value end end if attributes.key?(:'ultimate_beneficial_owners') if (value = attributes[:'ultimate_beneficial_owners']).is_a?(Array) self.ultimate_beneficial_owners = value end end if attributes.key?(:'supporting_file_guids') if (value = attributes[:'supporting_file_guids']).is_a?(Array) self.supporting_file_guids = value end end if attributes.key?(:'registered_address') self.registered_address = attributes[:'registered_address'] end if attributes.key?(:'business_industry') self.business_industry = attributes[:'business_industry'] end if attributes.key?(:'business_funds_source') self.business_funds_source = attributes[:'business_funds_source'] end if attributes.key?(:'business_funds_destination') self.business_funds_destination = attributes[:'business_funds_destination'] end if attributes.key?(:'business_type') self.business_type = attributes[:'business_type'] end if attributes.key?(:'business_incorporation_date') self.business_incorporation_date = attributes[:'business_incorporation_date'] end if attributes.key?(:'occupation') self.occupation = attributes[:'occupation'] end if attributes.key?(:'citizenship') self.citizenship = attributes[:'citizenship'] end if attributes.key?(:'biometrics_verified') self.biometrics_verified = attributes[:'biometrics_verified'] end if attributes.key?(:'external_bank_account_guid') self.external_bank_account_guid = attributes[:'external_bank_account_guid'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
42 43 44 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 42 def address @address end |
#aliases ⇒ Object
The aliases of the customer. Optional when type is kyc and method is attested_business_registration or type is kyc and method is watchlists.
51 52 53 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 51 def aliases @aliases end |
#biometrics_verified ⇒ Object
Whether biometrics have been verified Required when type is kyc and method is attested_business_associate or type is kyc and method is attested_id_and_database.
98 99 100 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 98 def biometrics_verified @biometrics_verified end |
#business_funds_destination ⇒ Object
The destination of business funds. Required for attested business registration V3. e.g. 'To your business account (bank or wallet)', 'To vendors or suppliers', 'To employees or contractors', 'To sellers or merchants', 'Bulk payments or payouts', etc. Optional when type is kyc and method is attested_business_registration.
83 84 85 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 83 def business_funds_destination @business_funds_destination end |
#business_funds_source ⇒ Object
The source of business funds. Required for attested business registration V3. e.g. 'Funds from individual customers', 'Funds from business customers', 'Funds from both individual and business customers', etc. Optional when type is kyc and method is attested_business_registration.
80 81 82 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 80 def business_funds_source @business_funds_source end |
#business_incorporation_date ⇒ Object
The date the business was incorporated. Required for attested business registration V3. Optional when type is kyc and method is attested_business_registration.
89 90 91 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 89 def business_incorporation_date @business_incorporation_date end |
#business_industry ⇒ Object
The industry the business operates in. Required for attested business registration V3. Optional when type is kyc and method is attested_business_registration.
77 78 79 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 77 def business_industry @business_industry end |
#business_type ⇒ Object
The type of business. Defaults to 'entity' for V3. Optional when type is kyc and method is attested_business_registration.
86 87 88 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 86 def business_type @business_type end |
#citizenship ⇒ Object
The customer's citizenship country code. Required when type is kyc and method is attested_business_associate. Optional when type is kyc and method is attested_id_and_selfie, type is kyc and method is attested_id_and_database, or type is kyc and method is attested_database.
95 96 97 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 95 def citizenship @citizenship end |
#counterparty_guid ⇒ Object
The counterparty's identifier. Required when type is counterparty.
32 33 34 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 32 def counterparty_guid @counterparty_guid end |
#country_code ⇒ Object
The ISO 3166 country 2-Alpha country the customer is being verified in. If not present, will default to the Bank's configured country code. Optional when type is kyc and method is id_and_selfie, type is kyc and method is tax_id_and_selfie, type is kyc and method is business_registration, or type is kyc and method is database.
35 36 37 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 35 def country_code @country_code end |
#customer_guid ⇒ Object
The customer's identifier. Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_id_and_selfie, type is kyc and method is attested_business_associate, type is kyc and method is attested_id_and_database, or type is kyc and method is attested_database.
23 24 25 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 23 def customer_guid @customer_guid end |
#date_of_birth ⇒ Object
The customer's date of birth. Required when type is kyc and method is attested, type is kyc and method is attested_id_and_selfie, type is kyc and method is attested_business_associate, type is kyc and method is attested_id_and_database, or type is kyc and method is attested_database.
45 46 47 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 45 def date_of_birth @date_of_birth end |
#director_customer_guids ⇒ Object
The customer guids of the directors of the business Required when type is kyc and method is attested_business_registration.
66 67 68 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 66 def director_customer_guids @director_customer_guids end |
#email_address ⇒ Object
The customer's email address. Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_id_and_selfie, type is kyc and method is attested_business_associate, type is kyc and method is attested_id_and_database, or type is kyc and method is attested_database. Optional when type is bank_account and method is attested_ownership.
57 58 59 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 57 def email_address @email_address end |
#expected_behaviours ⇒ Object
The optional expected behaviour to simulate.
26 27 28 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 26 def expected_behaviours @expected_behaviours end |
#external_bank_account_guid ⇒ Object
The external bank account's identifier. Required when type is bank_account.
101 102 103 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 101 def external_bank_account_guid @external_bank_account_guid end |
#identification_numbers ⇒ Object
The customer's identification numbers. Required when type is kyc and method is attested, type is kyc and method is attested_business_registration, type is kyc and method is attested_business_associate, type is kyc and method is attested_id_and_database, or type is kyc and method is attested_database. Optional when type is kyc and method is attested_id_and_selfie.
48 49 50 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 48 def identification_numbers @identification_numbers end |
#method ⇒ Object
The identity verification method. Required when type is counterparty, type is kyc, or type is bank_account.
29 30 31 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 29 def method @method end |
#name ⇒ Object
Returns the value of attribute name.
40 41 42 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 40 def name @name end |
#nature_of_business ⇒ Object
The customer's nature of business. Required when type is kyc and method is attested_business_registration.
63 64 65 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 63 def nature_of_business @nature_of_business end |
#occupation ⇒ Object
The customer's occupation. Required when type is kyc and method is attested_business_associate. Optional when type is kyc and method is attested_id_and_selfie.
92 93 94 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 92 def occupation @occupation end |
#phone_number ⇒ Object
The customer's phone number. Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_id_and_selfie, type is kyc and method is attested_business_associate, type is kyc and method is attested_id_and_database, or type is kyc and method is attested_database. Optional when type is bank_account and method is attested_ownership.
54 55 56 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 54 def phone_number @phone_number end |
#registered_address ⇒ Object
Returns the value of attribute registered_address.
74 75 76 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 74 def registered_address @registered_address end |
#require_tax_id ⇒ Object
Whether the collection of the tax id is required during identity verification. This will default to SSN in USA and SIN in Canada. It's not used elsewhere. Optional when type is kyc and method is id_and_selfie.
38 39 40 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 38 def require_tax_id @require_tax_id end |
#supporting_file_guids ⇒ Object
File guids supporting the verification Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_business_associate, or type is kyc and method is attested_id_and_database. Optional when type is kyc and method is attested_id_and_selfie.
72 73 74 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 72 def supporting_file_guids @supporting_file_guids end |
#type ⇒ Object
The type of identity verification.
20 21 22 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 20 def type @type end |
#ultimate_beneficial_owners ⇒ Object
The ultimate beneficial owners of the business with 25% or more ownership. Required for attested business registration V2, optional for V3. Optional when type is kyc and method is attested_business_registration.
69 70 71 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 69 def ultimate_beneficial_owners @ultimate_beneficial_owners end |
#website ⇒ Object
The customer's website. Required for attested business registration V2, optional for V3. Optional when type is kyc and method is attested_business_registration.
60 61 62 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 60 def website @website end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
161 162 163 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 161 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 126 def self.attribute_map { :'type' => :'type', :'customer_guid' => :'customer_guid', :'expected_behaviours' => :'expected_behaviours', :'method' => :'method', :'counterparty_guid' => :'counterparty_guid', :'country_code' => :'country_code', :'require_tax_id' => :'require_tax_id', :'name' => :'name', :'address' => :'address', :'date_of_birth' => :'date_of_birth', :'identification_numbers' => :'identification_numbers', :'aliases' => :'aliases', :'phone_number' => :'phone_number', :'email_address' => :'email_address', :'website' => :'website', :'nature_of_business' => :'nature_of_business', :'director_customer_guids' => :'director_customer_guids', :'ultimate_beneficial_owners' => :'ultimate_beneficial_owners', :'supporting_file_guids' => :'supporting_file_guids', :'registered_address' => :'registered_address', :'business_industry' => :'business_industry', :'business_funds_source' => :'business_funds_source', :'business_funds_destination' => :'business_funds_destination', :'business_type' => :'business_type', :'business_incorporation_date' => :'business_incorporation_date', :'occupation' => :'occupation', :'citizenship' => :'citizenship', :'biometrics_verified' => :'biometrics_verified', :'external_bank_account_guid' => :'external_bank_account_guid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
634 635 636 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 634 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 201 def self.openapi_nullable Set.new([ :'customer_guid', :'expected_behaviours', :'method', :'counterparty_guid', :'country_code', :'require_tax_id', :'name', :'address', :'date_of_birth', :'identification_numbers', :'aliases', :'phone_number', :'email_address', :'website', :'nature_of_business', :'director_customer_guids', :'ultimate_beneficial_owners', :'supporting_file_guids', :'registered_address', :'business_industry', :'business_funds_source', :'business_funds_destination', :'business_type', :'business_incorporation_date', :'occupation', :'citizenship', :'biometrics_verified', :'external_bank_account_guid' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 166 def self.openapi_types { :'type' => :'String', :'customer_guid' => :'String', :'expected_behaviours' => :'Array<String>', :'method' => :'String', :'counterparty_guid' => :'String', :'country_code' => :'String', :'require_tax_id' => :'Boolean', :'name' => :'PostIdentityVerificationNameBankModel', :'address' => :'PostIdentityVerificationAddressBankModel', :'date_of_birth' => :'Date', :'identification_numbers' => :'Array<PostIdentificationNumberBankModel>', :'aliases' => :'Array<PostIdentityVerificationAliasesInnerBankModel>', :'phone_number' => :'String', :'email_address' => :'String', :'website' => :'String', :'nature_of_business' => :'String', :'director_customer_guids' => :'Array<String>', :'ultimate_beneficial_owners' => :'Array<PostUltimateBeneficialOwnerBankModel>', :'supporting_file_guids' => :'Array<String>', :'registered_address' => :'PostIdentityVerificationRegisteredAddressBankModel', :'business_industry' => :'String', :'business_funds_source' => :'String', :'business_funds_destination' => :'String', :'business_type' => :'String', :'business_incorporation_date' => :'Date', :'occupation' => :'String', :'citizenship' => :'String', :'biometrics_verified' => :'Boolean', :'external_bank_account_guid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 585 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && customer_guid == o.customer_guid && expected_behaviours == o.expected_behaviours && method == o.method && counterparty_guid == o.counterparty_guid && country_code == o.country_code && require_tax_id == o.require_tax_id && name == o.name && address == o.address && date_of_birth == o.date_of_birth && identification_numbers == o.identification_numbers && aliases == o.aliases && phone_number == o.phone_number && email_address == o.email_address && website == o.website && nature_of_business == o.nature_of_business && director_customer_guids == o.director_customer_guids && ultimate_beneficial_owners == o.ultimate_beneficial_owners && supporting_file_guids == o.supporting_file_guids && registered_address == o.registered_address && business_industry == o.business_industry && business_funds_source == o.business_funds_source && business_funds_destination == o.business_funds_destination && business_type == o.business_type && business_incorporation_date == o.business_incorporation_date && occupation == o.occupation && citizenship == o.citizenship && biometrics_verified == o.biometrics_verified && external_bank_account_guid == o.external_bank_account_guid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 665 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CybridApiBank.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
736 737 738 739 740 741 742 743 744 745 746 747 748 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 736 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 641 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
621 622 623 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 621 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
627 628 629 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 627 def hash [type, customer_guid, expected_behaviours, method, counterparty_guid, country_code, require_tax_id, name, address, date_of_birth, identification_numbers, aliases, phone_number, email_address, website, nature_of_business, director_customer_guids, ultimate_beneficial_owners, supporting_file_guids, registered_address, business_industry, business_funds_source, business_funds_destination, business_type, business_incorporation_date, occupation, citizenship, biometrics_verified, external_bank_account_guid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 382 def list_invalid_properties invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if !@customer_guid.nil? && @customer_guid.to_s.length > 32 invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.') end if !@expected_behaviours.nil? && @expected_behaviours.length > 50 invalid_properties.push('invalid value for "expected_behaviours", number of items must be less than or equal to 50.') end if !@identification_numbers.nil? && @identification_numbers.length > 10 invalid_properties.push('invalid value for "identification_numbers", number of items must be less than or equal to 10.') end if !@identification_numbers.nil? && @identification_numbers.length < 1 invalid_properties.push('invalid value for "identification_numbers", number of items must be greater than or equal to 1.') end if !@aliases.nil? && @aliases.length < 0 invalid_properties.push('invalid value for "aliases", number of items must be greater than or equal to 0.') end if !@nature_of_business.nil? && @nature_of_business.to_s.length > 256 invalid_properties.push('invalid value for "nature_of_business", the character length must be smaller than or equal to 256.') end if !@director_customer_guids.nil? && @director_customer_guids.length > 50 invalid_properties.push('invalid value for "director_customer_guids", number of items must be less than or equal to 50.') end if !@director_customer_guids.nil? && @director_customer_guids.length < 1 invalid_properties.push('invalid value for "director_customer_guids", number of items must be greater than or equal to 1.') end if !@ultimate_beneficial_owners.nil? && @ultimate_beneficial_owners.length > 50 invalid_properties.push('invalid value for "ultimate_beneficial_owners", number of items must be less than or equal to 50.') end if !@supporting_file_guids.nil? && @supporting_file_guids.length > 10 invalid_properties.push('invalid value for "supporting_file_guids", number of items must be less than or equal to 10.') end if !@supporting_file_guids.nil? && @supporting_file_guids.length < 1 invalid_properties.push('invalid value for "supporting_file_guids", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
712 713 714 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 712 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
718 719 720 721 722 723 724 725 726 727 728 729 730 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 718 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
706 707 708 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 706 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 437 def valid? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["kyc", "bank_account", "counterparty"]) return false unless type_validator.valid?(@type) return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32 return false if !@expected_behaviours.nil? && @expected_behaviours.length > 50 method_validator = EnumAttributeValidator.new('String', ["watchlists", "attested", "document_submission", "enhanced_due_diligence", "id_and_selfie", "tax_id_and_selfie", "business_registration", "attested_id_and_selfie", "attested_business_registration", "attested_business_associate", "attested_id_and_database", "attested_database", "database", "attested_ownership", "account_ownership"]) return false unless method_validator.valid?(@method) return false if !@identification_numbers.nil? && @identification_numbers.length > 10 return false if !@identification_numbers.nil? && @identification_numbers.length < 1 return false if !@aliases.nil? && @aliases.length < 0 return false if !@nature_of_business.nil? && @nature_of_business.to_s.length > 256 return false if !@director_customer_guids.nil? && @director_customer_guids.length > 50 return false if !@director_customer_guids.nil? && @director_customer_guids.length < 1 return false if !@ultimate_beneficial_owners.nil? && @ultimate_beneficial_owners.length > 50 return false if !@supporting_file_guids.nil? && @supporting_file_guids.length > 10 return false if !@supporting_file_guids.nil? && @supporting_file_guids.length < 1 business_industry_validator = EnumAttributeValidator.new('String', ["crypto_digital_assets_blockchain", "education", "gaming", "healthcare_hospitality", "lending_investments", "logistics_manufacturing_transportation", "money_services_payments_remittance", "consulting_legal_accounting", "real_estate_property_management", "retail_ecommerce", "social_media_content_creator_influencer", "technology_software_saas", "wholesale_distribution", "other"]) return false unless business_industry_validator.valid?(@business_industry) business_type_validator = EnumAttributeValidator.new('String', ["entity", "sole_proprietor"]) return false unless business_type_validator.valid?(@business_type) true end |