Class: CybridApiBank::PostIdentityVerificationBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb

Overview

Request body for identity verification creation.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PostIdentityVerificationBankModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 218

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::PostIdentityVerificationBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::PostIdentityVerificationBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'expected_behaviours')
    if (value = attributes[:'expected_behaviours']).is_a?(Array)
      self.expected_behaviours = value
    end
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'counterparty_guid')
    self.counterparty_guid = attributes[:'counterparty_guid']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  end

  if attributes.key?(:'require_tax_id')
    self.require_tax_id = attributes[:'require_tax_id']
  else
    self.require_tax_id = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'identification_numbers')
    if (value = attributes[:'identification_numbers']).is_a?(Array)
      self.identification_numbers = value
    end
  end

  if attributes.key?(:'aliases')
    if (value = attributes[:'aliases']).is_a?(Array)
      self.aliases = value
    end
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'nature_of_business')
    self.nature_of_business = attributes[:'nature_of_business']
  end

  if attributes.key?(:'director_customer_guids')
    if (value = attributes[:'director_customer_guids']).is_a?(Array)
      self.director_customer_guids = value
    end
  end

  if attributes.key?(:'ultimate_beneficial_owners')
    if (value = attributes[:'ultimate_beneficial_owners']).is_a?(Array)
      self.ultimate_beneficial_owners = value
    end
  end

  if attributes.key?(:'supporting_file_guids')
    if (value = attributes[:'supporting_file_guids']).is_a?(Array)
      self.supporting_file_guids = value
    end
  end

  if attributes.key?(:'registered_address')
    self.registered_address = attributes[:'registered_address']
  end

  if attributes.key?(:'business_industry')
    self.business_industry = attributes[:'business_industry']
  end

  if attributes.key?(:'business_funds_source')
    self.business_funds_source = attributes[:'business_funds_source']
  end

  if attributes.key?(:'business_funds_destination')
    self.business_funds_destination = attributes[:'business_funds_destination']
  end

  if attributes.key?(:'occupation')
    self.occupation = attributes[:'occupation']
  end

  if attributes.key?(:'biometrics_verified')
    self.biometrics_verified = attributes[:'biometrics_verified']
  end

  if attributes.key?(:'external_bank_account_guid')
    self. = attributes[:'external_bank_account_guid']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



42
43
44
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 42

def address
  @address
end

#aliasesObject

The aliases of the customer. Optional when type is kyc and method is attested_business_registration or type is kyc and method is watchlists.



51
52
53
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 51

def aliases
  @aliases
end

#biometrics_verifiedObject

Whether biometrics have been verified Required when type is kyc and method is attested_business_associate.



89
90
91
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 89

def biometrics_verified
  @biometrics_verified
end

#business_funds_destinationObject

The destination of business funds. Required for attested business registration V3. e.g. ‘To your business account (bank or wallet)’, ‘To vendors or suppliers’, ‘To employees or contractors’, ‘To sellers or merchants’, ‘Bulk payments or payouts’, etc. Optional when type is kyc and method is attested_business_registration.



83
84
85
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 83

def business_funds_destination
  @business_funds_destination
end

#business_funds_sourceObject

The source of business funds. Required for attested business registration V3. e.g. ‘Funds from individual customers’, ‘Funds from business customers’, ‘Funds from both individual and business customers’, etc. Optional when type is kyc and method is attested_business_registration.



80
81
82
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 80

def business_funds_source
  @business_funds_source
end

#business_industryObject

The industry the business operates in. Required for attested business registration V3. e.g. ‘Crypto / Digital Assets / Blockchain’, ‘Education’, ‘Gaming’, ‘Healthcare / Hospitality’, ‘Lending / Investments’, ‘Retail / E-Commerce’, etc. Optional when type is kyc and method is attested_business_registration.



77
78
79
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 77

def business_industry
  @business_industry
end

#counterparty_guidObject

The counterparty’s identifier. Required when type is counterparty.



32
33
34
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 32

def counterparty_guid
  @counterparty_guid
end

#country_codeObject

The ISO 3166 country 2-Alpha country the customer is being verified in. If not present, will default to the Bank’s configured country code. Optional when type is kyc and method is id_and_selfie, type is kyc and method is tax_id_and_selfie, or type is kyc and method is business_registration.



35
36
37
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 35

def country_code
  @country_code
end

#customer_guidObject

The customer’s identifier. Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_id_and_selfie, or type is kyc and method is attested_business_associate.



23
24
25
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 23

def customer_guid
  @customer_guid
end

#date_of_birthObject

The customer’s date of birth. Required when type is kyc and method is attested, type is kyc and method is attested_id_and_selfie, or type is kyc and method is attested_business_associate.



45
46
47
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 45

def date_of_birth
  @date_of_birth
end

#director_customer_guidsObject

The customer guids of the directors of the business Required when type is kyc and method is attested_business_registration.



66
67
68
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 66

def director_customer_guids
  @director_customer_guids
end

#email_addressObject

The customer’s email address. Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_id_and_selfie, or type is kyc and method is attested_business_associate. Optional when type is bank_account and method is attested_ownership.



57
58
59
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 57

def email_address
  @email_address
end

#expected_behavioursObject

The optional expected behaviour to simulate.



26
27
28
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 26

def expected_behaviours
  @expected_behaviours
end

#external_bank_account_guidObject

The external bank account’s identifier. Required when type is bank_account.



92
93
94
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 92

def 
  
end

#identification_numbersObject

The customer’s identification numbers. Required when type is kyc and method is attested, type is kyc and method is attested_business_registration, type is kyc and method is attested_id_and_selfie, or type is kyc and method is attested_business_associate.



48
49
50
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 48

def identification_numbers
  @identification_numbers
end

#methodObject

The identity verification method. Required when type is counterparty, type is kyc, or type is bank_account.



29
30
31
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 29

def method
  @method
end

#nameObject

Returns the value of attribute name.



40
41
42
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 40

def name
  @name
end

#nature_of_businessObject

The customer’s nature of business. Required when type is kyc and method is attested_business_registration.



63
64
65
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 63

def nature_of_business
  @nature_of_business
end

#occupationObject

The customer’s occupation. Required when type is kyc and method is attested_business_associate. Optional when type is kyc and method is attested_id_and_selfie.



86
87
88
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 86

def occupation
  @occupation
end

#phone_numberObject

The customer’s phone number. Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_id_and_selfie, or type is kyc and method is attested_business_associate. Optional when type is bank_account and method is attested_ownership.



54
55
56
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 54

def phone_number
  @phone_number
end

#registered_addressObject

Returns the value of attribute registered_address.



74
75
76
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 74

def registered_address
  @registered_address
end

#require_tax_idObject

Whether the collection of the tax id is required during identity verification. This will default to SSN in USA and SIN in Canada. It’s not used elsewhere. Optional when type is kyc and method is id_and_selfie.



38
39
40
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 38

def require_tax_id
  @require_tax_id
end

#supporting_file_guidsObject

File guids supporting the verification Required when type is kyc and method is attested_business_registration, type is kyc and method is attested_id_and_selfie, or type is kyc and method is attested_business_associate.



72
73
74
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 72

def supporting_file_guids
  @supporting_file_guids
end

#typeObject

The type of identity verification.



20
21
22
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 20

def type
  @type
end

#ultimate_beneficial_ownersObject

The ultimate beneficial owners of the business with 10% or more ownership Required when type is kyc and method is attested_business_registration.



69
70
71
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 69

def ultimate_beneficial_owners
  @ultimate_beneficial_owners
end

#websiteObject

The customer’s website. Required when type is kyc and method is attested_business_registration.



60
61
62
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 60

def website
  @website
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



149
150
151
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 149

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 117

def self.attribute_map
  {
    :'type' => :'type',
    :'customer_guid' => :'customer_guid',
    :'expected_behaviours' => :'expected_behaviours',
    :'method' => :'method',
    :'counterparty_guid' => :'counterparty_guid',
    :'country_code' => :'country_code',
    :'require_tax_id' => :'require_tax_id',
    :'name' => :'name',
    :'address' => :'address',
    :'date_of_birth' => :'date_of_birth',
    :'identification_numbers' => :'identification_numbers',
    :'aliases' => :'aliases',
    :'phone_number' => :'phone_number',
    :'email_address' => :'email_address',
    :'website' => :'website',
    :'nature_of_business' => :'nature_of_business',
    :'director_customer_guids' => :'director_customer_guids',
    :'ultimate_beneficial_owners' => :'ultimate_beneficial_owners',
    :'supporting_file_guids' => :'supporting_file_guids',
    :'registered_address' => :'registered_address',
    :'business_industry' => :'business_industry',
    :'business_funds_source' => :'business_funds_source',
    :'business_funds_destination' => :'business_funds_destination',
    :'occupation' => :'occupation',
    :'biometrics_verified' => :'biometrics_verified',
    :'external_bank_account_guid' => :'external_bank_account_guid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



571
572
573
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 571

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 186

def self.openapi_nullable
  Set.new([
    :'customer_guid',
    :'expected_behaviours',
    :'method',
    :'counterparty_guid',
    :'country_code',
    :'require_tax_id',
    :'name',
    :'address',
    :'date_of_birth',
    :'identification_numbers',
    :'aliases',
    :'phone_number',
    :'email_address',
    :'website',
    :'nature_of_business',
    :'director_customer_guids',
    :'ultimate_beneficial_owners',
    :'supporting_file_guids',
    :'registered_address',
    :'business_industry',
    :'business_funds_source',
    :'business_funds_destination',
    :'occupation',
    :'biometrics_verified',
    :'external_bank_account_guid'
  ])
end

.openapi_typesObject

Attribute type mapping.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 154

def self.openapi_types
  {
    :'type' => :'String',
    :'customer_guid' => :'String',
    :'expected_behaviours' => :'Array<String>',
    :'method' => :'String',
    :'counterparty_guid' => :'String',
    :'country_code' => :'String',
    :'require_tax_id' => :'Boolean',
    :'name' => :'PostIdentityVerificationNameBankModel',
    :'address' => :'PostIdentityVerificationAddressBankModel',
    :'date_of_birth' => :'Date',
    :'identification_numbers' => :'Array<PostIdentificationNumberBankModel>',
    :'aliases' => :'Array<PostIdentityVerificationAliasesInnerBankModel>',
    :'phone_number' => :'String',
    :'email_address' => :'String',
    :'website' => :'String',
    :'nature_of_business' => :'String',
    :'director_customer_guids' => :'Array<String>',
    :'ultimate_beneficial_owners' => :'Array<PostUltimateBeneficialOwnerBankModel>',
    :'supporting_file_guids' => :'Array<String>',
    :'registered_address' => :'PostIdentityVerificationRegisteredAddressBankModel',
    :'business_industry' => :'String',
    :'business_funds_source' => :'String',
    :'business_funds_destination' => :'String',
    :'occupation' => :'String',
    :'biometrics_verified' => :'Boolean',
    :'external_bank_account_guid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 525

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      customer_guid == o.customer_guid &&
      expected_behaviours == o.expected_behaviours &&
      method == o.method &&
      counterparty_guid == o.counterparty_guid &&
      country_code == o.country_code &&
      require_tax_id == o.require_tax_id &&
      name == o.name &&
      address == o.address &&
      date_of_birth == o.date_of_birth &&
      identification_numbers == o.identification_numbers &&
      aliases == o.aliases &&
      phone_number == o.phone_number &&
      email_address == o.email_address &&
      website == o.website &&
      nature_of_business == o.nature_of_business &&
      director_customer_guids == o.director_customer_guids &&
      ultimate_beneficial_owners == o.ultimate_beneficial_owners &&
      supporting_file_guids == o.supporting_file_guids &&
      registered_address == o.registered_address &&
      business_industry == o.business_industry &&
      business_funds_source == o.business_funds_source &&
      business_funds_destination == o.business_funds_destination &&
      occupation == o.occupation &&
      biometrics_verified == o.biometrics_verified &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 602

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



673
674
675
676
677
678
679
680
681
682
683
684
685
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 673

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 578

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


558
559
560
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 558

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



564
565
566
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 564

def hash
  [type, customer_guid, expected_behaviours, method, counterparty_guid, country_code, require_tax_id, name, address, date_of_birth, identification_numbers, aliases, phone_number, email_address, website, nature_of_business, director_customer_guids, ultimate_beneficial_owners, supporting_file_guids, registered_address, business_industry, business_funds_source, business_funds_destination, occupation, biometrics_verified, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 352

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@expected_behaviours.nil? && @expected_behaviours.length > 50
    invalid_properties.push('invalid value for "expected_behaviours", number of items must be less than or equal to 50.')
  end

  if !@identification_numbers.nil? && @identification_numbers.length > 10
    invalid_properties.push('invalid value for "identification_numbers", number of items must be less than or equal to 10.')
  end

  if !@identification_numbers.nil? && @identification_numbers.length < 1
    invalid_properties.push('invalid value for "identification_numbers", number of items must be greater than or equal to 1.')
  end

  if !@aliases.nil? && @aliases.length < 0
    invalid_properties.push('invalid value for "aliases", number of items must be greater than or equal to 0.')
  end

  if !@director_customer_guids.nil? && @director_customer_guids.length > 50
    invalid_properties.push('invalid value for "director_customer_guids", number of items must be less than or equal to 50.')
  end

  if !@director_customer_guids.nil? && @director_customer_guids.length < 1
    invalid_properties.push('invalid value for "director_customer_guids", number of items must be greater than or equal to 1.')
  end

  if !@ultimate_beneficial_owners.nil? && @ultimate_beneficial_owners.length > 50
    invalid_properties.push('invalid value for "ultimate_beneficial_owners", number of items must be less than or equal to 50.')
  end

  if !@ultimate_beneficial_owners.nil? && @ultimate_beneficial_owners.length < 1
    invalid_properties.push('invalid value for "ultimate_beneficial_owners", number of items must be greater than or equal to 1.')
  end

  if !@supporting_file_guids.nil? && @supporting_file_guids.length > 10
    invalid_properties.push('invalid value for "supporting_file_guids", number of items must be less than or equal to 10.')
  end

  if !@supporting_file_guids.nil? && @supporting_file_guids.length < 1
    invalid_properties.push('invalid value for "supporting_file_guids", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



649
650
651
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 649

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



655
656
657
658
659
660
661
662
663
664
665
666
667
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 655

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



643
644
645
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 643

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/cybrid_api_bank_ruby/models/post_identity_verification_bank_model.rb', line 407

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["kyc", "bank_account", "counterparty"])
  return false unless type_validator.valid?(@type)
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@expected_behaviours.nil? && @expected_behaviours.length > 50
  method_validator = EnumAttributeValidator.new('String', ["watchlists", "attested", "document_submission", "enhanced_due_diligence", "id_and_selfie", "tax_id_and_selfie", "business_registration", "attested_id_and_selfie", "attested_business_registration", "attested_business_associate", "attested_ownership", "account_ownership"])
  return false unless method_validator.valid?(@method)
  return false if !@identification_numbers.nil? && @identification_numbers.length > 10
  return false if !@identification_numbers.nil? && @identification_numbers.length < 1
  return false if !@aliases.nil? && @aliases.length < 0
  return false if !@director_customer_guids.nil? && @director_customer_guids.length > 50
  return false if !@director_customer_guids.nil? && @director_customer_guids.length < 1
  return false if !@ultimate_beneficial_owners.nil? && @ultimate_beneficial_owners.length > 50
  return false if !@ultimate_beneficial_owners.nil? && @ultimate_beneficial_owners.length < 1
  return false if !@supporting_file_guids.nil? && @supporting_file_guids.length > 10
  return false if !@supporting_file_guids.nil? && @supporting_file_guids.length < 1
  true
end