Class: CybridApiBank::TransferBankModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TransferBankModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 244

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiBank::TransferBankModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiBank::TransferBankModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'guid')
    self.guid = attributes[:'guid']
  end

  if attributes.key?(:'transfer_type')
    self.transfer_type = attributes[:'transfer_type']
  end

  if attributes.key?(:'bank_guid')
    self.bank_guid = attributes[:'bank_guid']
  end

  if attributes.key?(:'customer_guid')
    self.customer_guid = attributes[:'customer_guid']
  end

  if attributes.key?(:'quote_guid')
    self.quote_guid = attributes[:'quote_guid']
  end

  if attributes.key?(:'external_bank_account_guid')
    self. = attributes[:'external_bank_account_guid']
  end

  if attributes.key?(:'asset')
    self.asset = attributes[:'asset']
  end

  if attributes.key?(:'side')
    self.side = attributes[:'side']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'failure_code')
    self.failure_code = attributes[:'failure_code']
  end

  if attributes.key?(:'return_code')
    self.return_code = attributes[:'return_code']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'estimated_amount')
    self.estimated_amount = attributes[:'estimated_amount']
  end

  if attributes.key?(:'fee')
    self.fee = attributes[:'fee']
  end

  if attributes.key?(:'fee_details')
    if (value = attributes[:'fee_details']).is_a?(Array)
      self.fee_details = value
    end
  end

  if attributes.key?(:'estimated_network_fee')
    self.estimated_network_fee = attributes[:'estimated_network_fee']
  end

  if attributes.key?(:'network_fee')
    self.network_fee = attributes[:'network_fee']
  end

  if attributes.key?(:'network_fee_asset')
    self.network_fee_asset = attributes[:'network_fee_asset']
  end

  if attributes.key?(:'network_fee_liability_amount')
    self.network_fee_liability_amount = attributes[:'network_fee_liability_amount']
  end

  if attributes.key?(:'network_fee_liability_amount_asset')
    self.network_fee_liability_amount_asset = attributes[:'network_fee_liability_amount_asset']
  end

  if attributes.key?(:'txn_hash')
    self.txn_hash = attributes[:'txn_hash']
  end

  if attributes.key?(:'identifiers')
    if (value = attributes[:'identifiers']).is_a?(Array)
      self.identifiers = value
    end
  end

  if attributes.key?(:'reference_transfer_guid')
    self.reference_transfer_guid = attributes[:'reference_transfer_guid']
  end

  if attributes.key?(:'source_account')
    self. = attributes[:'source_account']
  end

  if attributes.key?(:'source_participants')
    if (value = attributes[:'source_participants']).is_a?(Array)
      self.source_participants = value
    end
  end

  if attributes.key?(:'destination_account')
    self. = attributes[:'destination_account']
  end

  if attributes.key?(:'destination_participants')
    if (value = attributes[:'destination_participants']).is_a?(Array)
      self.destination_participants = value
    end
  end

  if attributes.key?(:'deposit_address_guid')
    self.deposit_address_guid = attributes[:'deposit_address_guid']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'hold_details')
    self.hold_details = attributes[:'hold_details']
  end

  if attributes.key?(:'transfer_details')
    self.transfer_details = attributes[:'transfer_details']
  end

  if attributes.key?(:'payment_rail')
    self.payment_rail = attributes[:'payment_rail']
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end

  if attributes.key?(:'entries')
    if (value = attributes[:'entries']).is_a?(Array)
      self.entries = value
    end
  end
end

Instance Attribute Details

#amount ⇒ Object

The actual amount in base units of the asset.



52
53
54
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 52

def amount
  @amount
end

#asset ⇒ Object

The asset the transfer is related to, e.g., USD.



37
38
39
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 37

def asset
  @asset
end

#bank_guid ⇒ Object

The associated bank's identifier.



25
26
27
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 25

def bank_guid
  @bank_guid
end

#created_at ⇒ Object

ISO8601 datetime the record was created at.



101
102
103
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 101

def created_at
  @created_at
end

#customer_guid ⇒ Object

The associated customer's identifier.



28
29
30
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 28

def customer_guid
  @customer_guid
end

#deposit_address_guid ⇒ Object

The guid of the deposit address. Only present on crypto deposits.



98
99
100
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 98

def deposit_address_guid
  @deposit_address_guid
end

#destination_account ⇒ Object

Returns the value of attribute destination_account.



92
93
94
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 92

def 
  @destination_account
end

#destination_participants ⇒ Object

The participants in the source account.



95
96
97
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 95

def destination_participants
  @destination_participants
end

#entries ⇒ Object

Transfer entries associated with the batch transfer



121
122
123
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 121

def entries
  @entries
end

#estimated_amount ⇒ Object

The estimated amount in base units of the asset.



55
56
57
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 55

def estimated_amount
  @estimated_amount
end

#estimated_network_fee ⇒ Object

The estimated network fee in base units of network_fee_asset. Only present on crypto transfers.



64
65
66
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 64

def estimated_network_fee
  @estimated_network_fee
end

#external_bank_account_guid ⇒ Object

The associated external bank account's identifier.



34
35
36
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 34

def 
  @external_bank_account_guid
end

#external_id ⇒ Object

The external identifier for the transfer.



115
116
117
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 115

def external_id
  @external_id
end

#failure_code ⇒ Object

The failure code for failed transfers; one of non_sufficient_funds, refresh_required, party_name_invalid, payment_rail_invalid, compliance_rejection, cancelled, reversed, limit_exceeded, network_fee_too_low, amount_too_low, internal_error, invalid_address, invalid_destination, customer_action_required, external_vendor_error, payment_request_expired, return_risk_exceeded, daily_limit_exceeded, weekly_limit_exceeded, monthly_limit_exceeded, customer_contact_info_missing, or recipient_cancelled.



46
47
48
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 46

def failure_code
  @failure_code
end

#fee ⇒ Object

The fee associated with the transfer. Represents the sum of the bank and platform fees.



58
59
60
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 58

def fee
  @fee
end

#fee_details ⇒ Object

The fees associated with the transfer.



61
62
63
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 61

def fee_details
  @fee_details
end

#guid ⇒ Object

Auto-generated unique identifier for the transfer.



19
20
21
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 19

def guid
  @guid
end

#hold_details ⇒ Object

Returns the value of attribute hold_details.



106
107
108
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 106

def hold_details
  @hold_details
end

#identifiers ⇒ Object

Array of identifiers associated with this transfer (transaction hash, wire reference numbers)



82
83
84
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 82

def identifiers
  @identifiers
end

#labels ⇒ Object

The labels associated with the transfer.



118
119
120
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 118

def labels
  @labels
end

#network_fee ⇒ Object

The actual network fee in base units of network_fee_asset. Only present on crypto transfers that have successfully completed.



67
68
69
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 67

def network_fee
  @network_fee
end

#network_fee_asset ⇒ Object

The asset code of the network fee. Only present on crypto transfers that have successfully completed.



70
71
72
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 70

def network_fee_asset
  @network_fee_asset
end

#network_fee_liability_amount ⇒ Object

The equivalent fiat network fee in base units of network_fee_liability_amount_asset. Only present on crypto transfers that have successfully completed.



73
74
75
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 73

def network_fee_liability_amount
  @network_fee_liability_amount
end

#network_fee_liability_amount_asset ⇒ Object

The fiat asset the network_fee_liability_amount is denominated in. Only present on crypto transfers that have successfully completed.



76
77
78
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 76

def network_fee_liability_amount_asset
  @network_fee_liability_amount_asset
end

#payment_rail ⇒ Object

The rail the payment was done on. One of: ach, eft, wire, rtp, etransfer



112
113
114
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 112

def payment_rail
  @payment_rail
end

#quote_guid ⇒ Object

The associated quote's identifier.



31
32
33
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 31

def quote_guid
  @quote_guid
end

#reference_transfer_guid ⇒ Object

The guid of the related transfer. Only present on return type transfers.



85
86
87
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 85

def reference_transfer_guid
  @reference_transfer_guid
end

#return_code ⇒ Object

The return code for reversed transfers



49
50
51
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 49

def return_code
  @return_code
end

#side ⇒ Object

The direction of the quote; one of deposit or withdrawal.



40
41
42
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 40

def side
  @side
end

#source_account ⇒ Object

Returns the value of attribute source_account.



87
88
89
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 87

def 
  @source_account
end

#source_participants ⇒ Object

The participants in the source account.



90
91
92
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 90

def source_participants
  @source_participants
end

#state ⇒ Object

The state of the transfer; one of storing, pending, holding, reviewing, completed, failed, or cancelling.



43
44
45
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 43

def state
  @state
end

#transfer_details ⇒ Object

The raw details on the transfer from the bank.



109
110
111
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 109

def transfer_details
  @transfer_details
end

#transfer_type ⇒ Object

The type of transfer; one of funding, book, crypto, instant_funding, funding_return, crypto_return, loss_recovery, inter_account, lightning, or instant_funding_return.



22
23
24
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 22

def transfer_type
  @transfer_type
end

#txn_hash ⇒ Object

The hash of the blockchain transaction (deprecated: use identifiers array)



79
80
81
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 79

def txn_hash
  @txn_hash
end

#updated_at ⇒ Object

ISO8601 datetime the record was last updated at.



104
105
106
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 104

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



166
167
168
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 166

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 124

def self.attribute_map
  {
    :'guid' => :'guid',
    :'transfer_type' => :'transfer_type',
    :'bank_guid' => :'bank_guid',
    :'customer_guid' => :'customer_guid',
    :'quote_guid' => :'quote_guid',
    :'external_bank_account_guid' => :'external_bank_account_guid',
    :'asset' => :'asset',
    :'side' => :'side',
    :'state' => :'state',
    :'failure_code' => :'failure_code',
    :'return_code' => :'return_code',
    :'amount' => :'amount',
    :'estimated_amount' => :'estimated_amount',
    :'fee' => :'fee',
    :'fee_details' => :'fee_details',
    :'estimated_network_fee' => :'estimated_network_fee',
    :'network_fee' => :'network_fee',
    :'network_fee_asset' => :'network_fee_asset',
    :'network_fee_liability_amount' => :'network_fee_liability_amount',
    :'network_fee_liability_amount_asset' => :'network_fee_liability_amount_asset',
    :'txn_hash' => :'txn_hash',
    :'identifiers' => :'identifiers',
    :'reference_transfer_guid' => :'reference_transfer_guid',
    :'source_account' => :'source_account',
    :'source_participants' => :'source_participants',
    :'destination_account' => :'destination_account',
    :'destination_participants' => :'destination_participants',
    :'deposit_address_guid' => :'deposit_address_guid',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'hold_details' => :'hold_details',
    :'transfer_details' => :'transfer_details',
    :'payment_rail' => :'payment_rail',
    :'external_id' => :'external_id',
    :'labels' => :'labels',
    :'entries' => :'entries'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



701
702
703
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 701

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 213

def self.openapi_nullable
  Set.new([
    :'bank_guid',
    :'customer_guid',
    :'external_bank_account_guid',
    :'failure_code',
    :'return_code',
    :'amount',
    :'estimated_network_fee',
    :'network_fee',
    :'network_fee_asset',
    :'network_fee_liability_amount',
    :'network_fee_liability_amount_asset',
    :'txn_hash',
    :'reference_transfer_guid',
    :'source_account',
    :'source_participants',
    :'destination_account',
    :'destination_participants',
    :'deposit_address_guid',
    :'hold_details',
    :'transfer_details',
    :'payment_rail',
    :'external_id',
    :'labels',
    :'entries'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 171

def self.openapi_types
  {
    :'guid' => :'String',
    :'transfer_type' => :'String',
    :'bank_guid' => :'String',
    :'customer_guid' => :'String',
    :'quote_guid' => :'String',
    :'external_bank_account_guid' => :'String',
    :'asset' => :'String',
    :'side' => :'String',
    :'state' => :'String',
    :'failure_code' => :'String',
    :'return_code' => :'String',
    :'amount' => :'Integer',
    :'estimated_amount' => :'Integer',
    :'fee' => :'Integer',
    :'fee_details' => :'Array<FeeDetailBankModel>',
    :'estimated_network_fee' => :'Integer',
    :'network_fee' => :'Integer',
    :'network_fee_asset' => :'String',
    :'network_fee_liability_amount' => :'Integer',
    :'network_fee_liability_amount_asset' => :'String',
    :'txn_hash' => :'String',
    :'identifiers' => :'Array<TransferIdentifiersInnerBankModel>',
    :'reference_transfer_guid' => :'String',
    :'source_account' => :'TransferSourceAccountBankModel',
    :'source_participants' => :'Array<TransferParticipantBankModel>',
    :'destination_account' => :'TransferDestinationAccountBankModel',
    :'destination_participants' => :'Array<TransferParticipantBankModel>',
    :'deposit_address_guid' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'hold_details' => :'TransferHoldDetailsBankModel',
    :'transfer_details' => :'Object',
    :'payment_rail' => :'String',
    :'external_id' => :'String',
    :'labels' => :'Array<String>',
    :'entries' => :'Array<TransferEntryBankModel>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 645

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      guid == o.guid &&
      transfer_type == o.transfer_type &&
      bank_guid == o.bank_guid &&
      customer_guid == o.customer_guid &&
      quote_guid == o.quote_guid &&
       == o. &&
      asset == o.asset &&
      side == o.side &&
      state == o.state &&
      failure_code == o.failure_code &&
      return_code == o.return_code &&
      amount == o.amount &&
      estimated_amount == o.estimated_amount &&
      fee == o.fee &&
      fee_details == o.fee_details &&
      estimated_network_fee == o.estimated_network_fee &&
      network_fee == o.network_fee &&
      network_fee_asset == o.network_fee_asset &&
      network_fee_liability_amount == o.network_fee_liability_amount &&
      network_fee_liability_amount_asset == o.network_fee_liability_amount_asset &&
      txn_hash == o.txn_hash &&
      identifiers == o.identifiers &&
      reference_transfer_guid == o.reference_transfer_guid &&
       == o. &&
      source_participants == o.source_participants &&
       == o. &&
      destination_participants == o.destination_participants &&
      deposit_address_guid == o.deposit_address_guid &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      hold_details == o.hold_details &&
      transfer_details == o.transfer_details &&
      payment_rail == o.payment_rail &&
      external_id == o.external_id &&
      labels == o.labels &&
      entries == o.entries
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 732

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiBank.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



803
804
805
806
807
808
809
810
811
812
813
814
815
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 803

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 708

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


688
689
690
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 688

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



694
695
696
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 694

def hash
  [guid, transfer_type, bank_guid, customer_guid, quote_guid, , asset, side, state, failure_code, return_code, amount, estimated_amount, fee, fee_details, estimated_network_fee, network_fee, network_fee_asset, network_fee_liability_amount, network_fee_liability_amount_asset, txn_hash, identifiers, reference_transfer_guid, , source_participants, , destination_participants, deposit_address_guid, created_at, updated_at, hold_details, transfer_details, payment_rail, external_id, labels, entries].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 416

def list_invalid_properties
  invalid_properties = Array.new
  if !@guid.nil? && @guid.to_s.length > 32
    invalid_properties.push('invalid value for "guid", the character length must be smaller than or equal to 32.')
  end

  if !@guid.nil? && @guid.to_s.length < 32
    invalid_properties.push('invalid value for "guid", the character length must be great than or equal to 32.')
  end

  if !@bank_guid.nil? && @bank_guid.to_s.length > 32
    invalid_properties.push('invalid value for "bank_guid", the character length must be smaller than or equal to 32.')
  end

  if !@bank_guid.nil? && @bank_guid.to_s.length < 32
    invalid_properties.push('invalid value for "bank_guid", the character length must be great than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@customer_guid.nil? && @customer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "customer_guid", the character length must be great than or equal to 32.')
  end

  if !@quote_guid.nil? && @quote_guid.to_s.length > 32
    invalid_properties.push('invalid value for "quote_guid", the character length must be smaller than or equal to 32.')
  end

  if !@quote_guid.nil? && @quote_guid.to_s.length < 32
    invalid_properties.push('invalid value for "quote_guid", the character length must be great than or equal to 32.')
  end

  if !@external_bank_account_guid.nil? && @external_bank_account_guid.to_s.length > 32
    invalid_properties.push('invalid value for "external_bank_account_guid", the character length must be smaller than or equal to 32.')
  end

  if !@external_bank_account_guid.nil? && @external_bank_account_guid.to_s.length < 32
    invalid_properties.push('invalid value for "external_bank_account_guid", the character length must be great than or equal to 32.')
  end

  if !@network_fee_asset.nil? && @network_fee_asset.to_s.length > 16
    invalid_properties.push('invalid value for "network_fee_asset", the character length must be smaller than or equal to 16.')
  end

  if !@network_fee_asset.nil? && @network_fee_asset.to_s.length < 1
    invalid_properties.push('invalid value for "network_fee_asset", the character length must be great than or equal to 1.')
  end

  if !@reference_transfer_guid.nil? && @reference_transfer_guid.to_s.length > 32
    invalid_properties.push('invalid value for "reference_transfer_guid", the character length must be smaller than or equal to 32.')
  end

  if !@reference_transfer_guid.nil? && @reference_transfer_guid.to_s.length < 32
    invalid_properties.push('invalid value for "reference_transfer_guid", the character length must be great than or equal to 32.')
  end

  if !@deposit_address_guid.nil? && @deposit_address_guid.to_s.length > 32
    invalid_properties.push('invalid value for "deposit_address_guid", the character length must be smaller than or equal to 32.')
  end

  if !@deposit_address_guid.nil? && @deposit_address_guid.to_s.length < 32
    invalid_properties.push('invalid value for "deposit_address_guid", the character length must be great than or equal to 32.')
  end

  if !@external_id.nil? && @external_id.to_s.length > 64
    invalid_properties.push('invalid value for "external_id", the character length must be smaller than or equal to 64.')
  end

  if !@external_id.nil? && @external_id.to_s.length < 1
    invalid_properties.push('invalid value for "external_id", the character length must be great than or equal to 1.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



779
780
781
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 779

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 785

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



773
774
775
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 773

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'lib/cybrid_api_bank_ruby/models/transfer_bank_model.rb', line 495

def valid?
  return false if !@guid.nil? && @guid.to_s.length > 32
  return false if !@guid.nil? && @guid.to_s.length < 32
  return false if !@bank_guid.nil? && @bank_guid.to_s.length > 32
  return false if !@bank_guid.nil? && @bank_guid.to_s.length < 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length > 32
  return false if !@customer_guid.nil? && @customer_guid.to_s.length < 32
  return false if !@quote_guid.nil? && @quote_guid.to_s.length > 32
  return false if !@quote_guid.nil? && @quote_guid.to_s.length < 32
  return false if !@external_bank_account_guid.nil? && @external_bank_account_guid.to_s.length > 32
  return false if !@external_bank_account_guid.nil? && @external_bank_account_guid.to_s.length < 32
  return false if !@network_fee_asset.nil? && @network_fee_asset.to_s.length > 16
  return false if !@network_fee_asset.nil? && @network_fee_asset.to_s.length < 1
  return false if !@reference_transfer_guid.nil? && @reference_transfer_guid.to_s.length > 32
  return false if !@reference_transfer_guid.nil? && @reference_transfer_guid.to_s.length < 32
  return false if !@deposit_address_guid.nil? && @deposit_address_guid.to_s.length > 32
  return false if !@deposit_address_guid.nil? && @deposit_address_guid.to_s.length < 32
  return false if !@external_id.nil? && @external_id.to_s.length > 64
  return false if !@external_id.nil? && @external_id.to_s.length < 1
  true
end