Class: CybridApiBank::TransfersBankApi
- Inherits:
-
Object
- Object
- CybridApiBank::TransfersBankApi
- Defined in:
- lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#cancel_transfer(transfer_guid, accept_version, opts = {}) ⇒ TransferBankModel
Cancel Transfer Initiates cancellation of an eligible funding transfer.
-
#cancel_transfer_with_http_info(transfer_guid, accept_version, opts = {}) ⇒ Array<(TransferBankModel, Integer, Hash)>
Cancel Transfer Initiates cancellation of an eligible funding transfer.
-
#create_transfer(post_transfer_bank_model, opts = {}) ⇒ TransferBankModel
Create Transfer Creates a transfer.
-
#create_transfer_with_http_info(post_transfer_bank_model, opts = {}) ⇒ Array<(TransferBankModel, Integer, Hash)>
Create Transfer Creates a transfer.
-
#get_transfer(transfer_guid, opts = {}) ⇒ TransferBankModel
Get Transfer Retrieves a transfer.
-
#get_transfer_with_http_info(transfer_guid, opts = {}) ⇒ Array<(TransferBankModel, Integer, Hash)>
Get Transfer Retrieves a transfer.
-
#initialize(api_client = ApiClient.default) ⇒ TransfersBankApi
constructor
A new instance of TransfersBankApi.
-
#list_transfers(opts = {}) ⇒ TransferListBankModel
Get transfers list Retrieves a listing of transfers.
-
#list_transfers_with_http_info(opts = {}) ⇒ Array<(TransferListBankModel, Integer, Hash)>
Get transfers list Retrieves a listing of transfers.
-
#update_transfer(transfer_guid, patch_transfer_bank_model, opts = {}) ⇒ TransferBankModel
Patch Transfer Update a transfer.
-
#update_transfer_with_http_info(transfer_guid, patch_transfer_bank_model, opts = {}) ⇒ Array<(TransferBankModel, Integer, Hash)>
Patch Transfer Update a transfer.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TransfersBankApi
Returns a new instance of TransfersBankApi.
19 20 21 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#cancel_transfer(transfer_guid, accept_version, opts = {}) ⇒ TransferBankModel
Cancel Transfer Initiates cancellation of an eligible funding transfer. Required scope: transfers:execute
28 29 30 31 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 28 def cancel_transfer(transfer_guid, accept_version, opts = {}) data, _status_code, _headers = cancel_transfer_with_http_info(transfer_guid, accept_version, opts) data end |
#cancel_transfer_with_http_info(transfer_guid, accept_version, opts = {}) ⇒ Array<(TransferBankModel, Integer, Hash)>
Cancel Transfer Initiates cancellation of an eligible funding transfer. Required scope: transfers:execute
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 39 def cancel_transfer_with_http_info(transfer_guid, accept_version, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TransfersBankApi.cancel_transfer ...' end # verify the required parameter 'transfer_guid' is set if @api_client.config.client_side_validation && transfer_guid.nil? fail ArgumentError, "Missing the required parameter 'transfer_guid' when calling TransfersBankApi.cancel_transfer" end # verify the required parameter 'accept_version' is set if @api_client.config.client_side_validation && accept_version.nil? fail ArgumentError, "Missing the required parameter 'accept_version' when calling TransfersBankApi.cancel_transfer" end # resource path local_var_path = '/api/transfers/{transfer_guid}'.sub('{' + 'transfer_guid' + '}', CGI.escape(transfer_guid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) header_params[:'Accept-Version'] = accept_version # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TransferBankModel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2'] = opts.merge( :operation => :"TransfersBankApi.cancel_transfer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TransfersBankApi#cancel_transfer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_transfer(post_transfer_bank_model, opts = {}) ⇒ TransferBankModel
Create Transfer
Creates a transfer. ## State | State | Description | |-------|-------------| | storing | The Platform is storing the transfer details in our private store | | reviewing | The Platform is reviewing the transfer for compliance | | pending | The Platform is executing the transfer | | completed | The Platform has successfully completed the transfer | | failed | The Platform was not able to successfully complete the transfer | ## Failure codes | Code | Description | |------|-------------| | amount_too_low | The transfer was rejected due to the amount being too low | | cancelled | The transfer was manually cancelled | | compliance_rejection | The transfer was rejected for compliance reasons | | internal_error | An internal error occurred while processing the transfer, please try again | | invalid_address | The destination address is invalid for transfer | | invalid_balance | There was insufficient balance for all required currencies to complete the transfer | | return_risk_exceeded | The risk of return is too high for this activity to be completed | | limit_exceeded | The customer is over the limits that have been set for them for this activity | | daily_limit_exceeded | The customer is over their daily limits for this activity | | weekly_limit_exceeded | The customer is over their weekly limits for this activity | | monthly_limit_exceeded | The customer is over their monthly limits for this activity | | lifetime_limit_exceeded | The customer is over their lifetime limits for this activity | | network_fee_too_low | The transfer was rejected due to the network fee being too low | | non_sufficient_funds | The customer does not have enough funds to complete the transfer | | party_name_invalid | The transfer's associated external bank account has an invalid party name | | payment_rail_invalid | The payment rail specified for the transfer is not supported by the external bank account | | payment_request_expired | The payment request expired before it could be completed | | plaid_access_not_granted | See the description from Plaid here | | plaid_institution_not_responding | See the description from Plaid here | | plaid_internal_server_error | See the description from Plaid here | | plaid_item_not_found | See the description from Plaid here | | plaid_item_not_supported | See the description from Plaid here | | plaid_multiple_accounts | Multiple accounts were selected through Plaid Link. | | plaid_no_accounts | See the description from Plaid here | | plaid_none_balances_error | The transfer was rejected due to an error with the balances retrieved by Plaid | | plaid_unknown_error | See the description from Plaid here | | refresh_required | The transfer's associated external_bank_account needs to be reconnected via Plaid | | invalid_destination | Issues with the destination details (invalid, closed, blocked) | | customer_action_required | Authorization declined or customer action required | | external_vendor_error | Unexpected error occurred with an external vendor or partner service during transfer processing | | reversed | The transfer was reversed | ## Failure codes that will result in a state change for the associated external bank account | Code | Description | |------|-------------| | refresh_required | The transfer was rejected due to the external bank account needing to be refreshed. The external bank account will be put in the state refresh_required | | plaid_access_not_granted | The transfer was rejected due to the external bank account needing to be reconnected via Plaid. The external bank account will be put in the state deleted | | plaid_item_not_found | The transfer was rejected due to the external bank account needing to be reconnected via Plaid. The external bank account will be put in the state deleted | | plaid_item_not_supported | The transfer was rejected because the account is not supported. A different account should be connected via Plaid. The external bank account will be put in the state deleted | | plaid_multiple_accounts | The transfer was rejected because multiple accounts were selected through Plaid Link. Only one account must be selected. The external bank account will be put in the state deleted | | plaid_no_accounts | The transfer was rejected because no compatible accounts could be found. The external bank account will be put in the state deleted | Required scope: transfers:execute
97 98 99 100 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 97 def create_transfer(post_transfer_bank_model, opts = {}) data, _status_code, _headers = create_transfer_with_http_info(post_transfer_bank_model, opts) data end |
#create_transfer_with_http_info(post_transfer_bank_model, opts = {}) ⇒ Array<(TransferBankModel, Integer, Hash)>
Create Transfer Creates a transfer. ## State | State | Description | |-------|-------------| | storing | The Platform is storing the transfer details in our private store | | reviewing | The Platform is reviewing the transfer for compliance | | pending | The Platform is executing the transfer | | completed | The Platform has successfully completed the transfer | | failed | The Platform was not able to successfully complete the transfer | ## Failure codes | Code | Description | |------|-------------| | amount_too_low | The transfer was rejected due to the amount being too low | | cancelled | The transfer was manually cancelled | | compliance_rejection | The transfer was rejected for compliance reasons | | internal_error | An internal error occurred while processing the transfer, please try again | | invalid_address | The destination address is invalid for transfer | | invalid_balance | There was insufficient balance for all required currencies to complete the transfer | | return_risk_exceeded | The risk of return is too high for this activity to be completed | | limit_exceeded | The customer is over the limits that have been set for them for this activity | | daily_limit_exceeded | The customer is over their daily limits for this activity | | weekly_limit_exceeded | The customer is over their weekly limits for this activity | | monthly_limit_exceeded | The customer is over their monthly limits for this activity | | lifetime_limit_exceeded | The customer is over their lifetime limits for this activity | | network_fee_too_low | The transfer was rejected due to the network fee being too low | | non_sufficient_funds | The customer does not have enough funds to complete the transfer | | party_name_invalid | The transfer's associated external bank account has an invalid party name | | payment_rail_invalid | The payment rail specified for the transfer is not supported by the external bank account | | payment_request_expired | The payment request expired before it could be completed | | plaid_access_not_granted | See the description from Plaid here | | plaid_institution_not_responding | See the description from Plaid here | | plaid_internal_server_error | See the description from Plaid here | | plaid_item_not_found | See the description from Plaid here | | plaid_item_not_supported | See the description from Plaid here | | plaid_multiple_accounts | Multiple accounts were selected through Plaid Link. | | plaid_no_accounts | See the description from Plaid here | | plaid_none_balances_error | The transfer was rejected due to an error with the balances retrieved by Plaid | | plaid_unknown_error | See the description from Plaid here | | refresh_required | The transfer's associated external_bank_account needs to be reconnected via Plaid | | invalid_destination | Issues with the destination details (invalid, closed, blocked) | | customer_action_required | Authorization declined or customer action required | | external_vendor_error | Unexpected error occurred with an external vendor or partner service during transfer processing | | reversed | The transfer was reversed | ## Failure codes that will result in a state change for the associated external bank account | Code | Description | |------|-------------| | refresh_required | The transfer was rejected due to the external bank account needing to be refreshed. The external bank account will be put in the state `refresh_required` | | plaid_access_not_granted | The transfer was rejected due to the external bank account needing to be reconnected via Plaid. The external bank account will be put in the state `deleted` | | plaid_item_not_found | The transfer was rejected due to the external bank account needing to be reconnected via Plaid. The external bank account will be put in the state `deleted` | | plaid_item_not_supported | The transfer was rejected because the account is not supported. A different account should be connected via Plaid. The external bank account will be put in the state `deleted` | | plaid_multiple_accounts | The transfer was rejected because multiple accounts were selected through Plaid Link. Only one account must be selected. The external bank account will be put in the state `deleted` | | plaid_no_accounts | The transfer was rejected because no compatible accounts could be found. The external bank account will be put in the state `deleted` | Required scope: transfers:execute
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 107 def create_transfer_with_http_info(post_transfer_bank_model, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TransfersBankApi.create_transfer ...' end # verify the required parameter 'post_transfer_bank_model' is set if @api_client.config.client_side_validation && post_transfer_bank_model.nil? fail ArgumentError, "Missing the required parameter 'post_transfer_bank_model' when calling TransfersBankApi.create_transfer" end # resource path local_var_path = '/api/transfers' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(post_transfer_bank_model) # return_type return_type = opts[:debug_return_type] || 'TransferBankModel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2'] = opts.merge( :operation => :"TransfersBankApi.create_transfer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TransfersBankApi#create_transfer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_transfer(transfer_guid, opts = {}) ⇒ TransferBankModel
Get Transfer Retrieves a transfer. Required scope: transfers:read
165 166 167 168 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 165 def get_transfer(transfer_guid, opts = {}) data, _status_code, _headers = get_transfer_with_http_info(transfer_guid, opts) data end |
#get_transfer_with_http_info(transfer_guid, opts = {}) ⇒ Array<(TransferBankModel, Integer, Hash)>
Get Transfer Retrieves a transfer. Required scope: transfers:read
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 175 def get_transfer_with_http_info(transfer_guid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TransfersBankApi.get_transfer ...' end # verify the required parameter 'transfer_guid' is set if @api_client.config.client_side_validation && transfer_guid.nil? fail ArgumentError, "Missing the required parameter 'transfer_guid' when calling TransfersBankApi.get_transfer" end # resource path local_var_path = '/api/transfers/{transfer_guid}'.sub('{' + 'transfer_guid' + '}', CGI.escape(transfer_guid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TransferBankModel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2'] = opts.merge( :operation => :"TransfersBankApi.get_transfer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TransfersBankApi#get_transfer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_transfers(opts = {}) ⇒ TransferListBankModel
Get transfers list Retrieves a listing of transfers. Records are sorted by creation date in descending order. Required scope: transfers:read
242 243 244 245 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 242 def list_transfers(opts = {}) data, _status_code, _headers = list_transfers_with_http_info(opts) data end |
#list_transfers_with_http_info(opts = {}) ⇒ Array<(TransferListBankModel, Integer, Hash)>
Get transfers list Retrieves a listing of transfers. Records are sorted by creation date in descending order. Required scope: transfers:read
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 266 def list_transfers_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TransfersBankApi.list_transfers ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 0 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling TransfersBankApi.list_transfers, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] > 100 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling TransfersBankApi.list_transfers, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'per_page'].nil? && opts[:'per_page'] < 1 fail ArgumentError, 'invalid value for "opts[:"per_page"]" when calling TransfersBankApi.list_transfers, must be greater than or equal to 1.' end # resource path local_var_path = '/api/transfers' # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'guid'] = opts[:'guid'] if !opts[:'guid'].nil? query_params[:'transfer_type'] = opts[:'transfer_type'] if !opts[:'transfer_type'].nil? query_params[:'bank_guid'] = opts[:'bank_guid'] if !opts[:'bank_guid'].nil? query_params[:'customer_guid'] = opts[:'customer_guid'] if !opts[:'customer_guid'].nil? query_params[:'account_guid'] = opts[:'account_guid'] if !opts[:'account_guid'].nil? query_params[:'state'] = opts[:'state'] if !opts[:'state'].nil? query_params[:'side'] = opts[:'side'] if !opts[:'side'].nil? query_params[:'label'] = opts[:'label'] if !opts[:'label'].nil? query_params[:'txn_hash'] = opts[:'txn_hash'] if !opts[:'txn_hash'].nil? query_params[:'created_at_gte'] = opts[:'created_at_gte'] if !opts[:'created_at_gte'].nil? query_params[:'created_at_lt'] = opts[:'created_at_lt'] if !opts[:'created_at_lt'].nil? query_params[:'updated_at_gte'] = opts[:'updated_at_gte'] if !opts[:'updated_at_gte'].nil? query_params[:'updated_at_lt'] = opts[:'updated_at_lt'] if !opts[:'updated_at_lt'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TransferListBankModel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2'] = opts.merge( :operation => :"TransfersBankApi.list_transfers", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TransfersBankApi#list_transfers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_transfer(transfer_guid, patch_transfer_bank_model, opts = {}) ⇒ TransferBankModel
Patch Transfer Update a transfer. Required scope: transfers:write
343 344 345 346 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 343 def update_transfer(transfer_guid, patch_transfer_bank_model, opts = {}) data, _status_code, _headers = update_transfer_with_http_info(transfer_guid, patch_transfer_bank_model, opts) data end |
#update_transfer_with_http_info(transfer_guid, patch_transfer_bank_model, opts = {}) ⇒ Array<(TransferBankModel, Integer, Hash)>
Patch Transfer Update a transfer. Required scope: transfers:write
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/cybrid_api_bank_ruby/api/transfers_bank_api.rb', line 354 def update_transfer_with_http_info(transfer_guid, patch_transfer_bank_model, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TransfersBankApi.update_transfer ...' end # verify the required parameter 'transfer_guid' is set if @api_client.config.client_side_validation && transfer_guid.nil? fail ArgumentError, "Missing the required parameter 'transfer_guid' when calling TransfersBankApi.update_transfer" end # verify the required parameter 'patch_transfer_bank_model' is set if @api_client.config.client_side_validation && patch_transfer_bank_model.nil? fail ArgumentError, "Missing the required parameter 'patch_transfer_bank_model' when calling TransfersBankApi.update_transfer" end # resource path local_var_path = '/api/transfers/{transfer_guid}'.sub('{' + 'transfer_guid' + '}', CGI.escape(transfer_guid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_transfer_bank_model) # return_type return_type = opts[:debug_return_type] || 'TransferBankModel' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth', 'oauth2'] = opts.merge( :operation => :"TransfersBankApi.update_transfer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TransfersBankApi#update_transfer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |